@@ -63,7 +63,8 @@ protected native void fstWriterSetEnvVar(long ctx, String envvar);
 protected native void fstWriterSetTimescaleFromString(long ctx, String s);
 protected native int fstWriterCreateVar(long ctx, int vt, int vd, int len, String nam, int aliasHandle);
 protected native int fstWriterCreateVar2(long ctx, int vt, int vd, int len, String nam, int aliasHandle, String type, int svt, int sdt);
-
+protected native void fstWriterSetSourceStem(long ctx, String path, int line, boolean use_realpath);
+protected native void fstWriterSetSourceInstantiationStem(long ctx, String path, int line, boolean use_realpath);
 protected native void fstWriterSetScope(long ctx, int scopetype, String scopename, String scopecomp);
 protected native void fstWriterEmitVariableLengthValueChange(long ctx, int handle, String val, int len);
 protected native void fstWriterSetAttrBegin(long ctx, int attrtype, int subtype, String attrname, long arg);
@@ -90,6 +91,7 @@ protected native long fstReaderGetValueChangeSectionCount(long ctx);
 protected native boolean fstReaderGetFseekFailed(long ctx);
 protected native void fstReaderSetUnlimitedTimeRange(long ctx);
 protected native void fstReaderSetLimitTimeRange(long ctx, long start_time, long end_time);
+protected native void fstReaderSetVcdExtensions(long ctx, boolean enable);
 protected native int fstReaderGetNumberDumpActivityChanges(long ctx);
 protected native long fstReaderGetDumpActivityChangeTime(long ctx, int idx);
 protected native boolean fstReaderGetFacProcessMask(long ctx, int facidx); 
