@@ -1,4 +1,4 @@
-/* 
+/*
  * Copyright (c) Tony Bybell 2004-2011.
  *
  * This program is free software; you can redistribute it and/or
@@ -28,16 +28,20 @@
 #include "busy.h"
 #include "hierpack.h"
 
-/* 
+/*
  * select appropriate entry points based on if aet2
  * support is available
  */
-#ifndef AET2_IS_PRESENT 
+#ifndef AET2_IS_PRESENT
 
 const char *ae2_loader_fail_msg = "Sorry, AET2 support was not compiled into this executable, exiting.\n\n";
 
 TimeType ae2_main(char *fname, char *skip_start, char *skip_end)
 {
+(void)fname;
+(void)skip_start;
+(void)skip_end;
+
 fprintf(stderr, "%s", ae2_loader_fail_msg);
 exit(255);
 
@@ -58,7 +62,7 @@ exit(255);
  */
 int aet2_rd_get_fac_process_mask(unsigned int facidx)
 {
-if(facidx<GLOBALS->numfacs)
+if((int)facidx<GLOBALS->numfacs)
 	{
 	int process_idx = facidx/8;
 	int process_bit = facidx&7;
@@ -72,7 +76,7 @@ return(0);
 
 void aet2_rd_set_fac_process_mask(unsigned int facidx)
 {
-if(facidx<GLOBALS->numfacs)
+if((int)facidx<GLOBALS->numfacs)
 	{
 	int idx = facidx/8;
 	int bitpos = facidx&7;
@@ -84,7 +88,7 @@ if(facidx<GLOBALS->numfacs)
 
 void aet2_rd_clr_fac_process_mask(unsigned int facidx)
 {
-if(facidx<GLOBALS->numfacs)
+if((int)facidx<GLOBALS->numfacs)
 	{
 	int idx = facidx/8;
 	int bitpos = facidx&7;
@@ -95,7 +99,7 @@ if(facidx<GLOBALS->numfacs)
 
 
 static void error_fn(const char *format, ...)
-{ 
+{
 va_list ap;
 va_start(ap, format);
 vfprintf(stderr, format, ap);
@@ -133,6 +137,8 @@ va_end(ap);
 
 static unsigned long symbol_fn (cchar *name, void *udata)
 {
+(void)udata;
+
 AE2_FACREF f2;
 return(ae2_read_find_symbol(GLOBALS->ae2, name, &f2));
 }
@@ -141,14 +147,16 @@ return(ae2_read_find_symbol(GLOBALS->ae2, name, &f2));
 
 
 static void *alloc_fn(size_t size)
-{        
+{
 void *pnt = calloc_2(1, size);
 return(pnt);
 }
 
-        
+
 static void free_fn(void* ptr, size_t size)
 {
+(void)size;
+
 if(ptr)
 	{
 	free_2(ptr);
@@ -218,7 +226,7 @@ if(numTerms)
 		{
 		ADB_TERM *at = &GLOBALS->adb_aliases[idx][i];
 		AE2_FACREF fr2;
-	
+
 		fr2.s = at->id;
 		fr2.row = 0;
 		fr2.row_high = 0;
@@ -270,7 +278,7 @@ if(numTerms)
 		{
 		ADB_TERM *at = &GLOBALS->adb_aliases[idx][i];
 		AE2_FACREF fr2;
-	
+
 		fr2.s = at->id;
 		fr2.row = 0;
 		fr2.row_high = 0;
@@ -284,7 +292,7 @@ if(numTerms)
 			{
 			fr2.length = -(length = at->first - at->last + 1);
 			}
-		
+
 		if(fr2.s)
 			{
 			t_cyc = ae2_read_next_value(handle, &fr2, cycle, value+offs); /* simply want to calculate next value change time */
@@ -423,7 +431,7 @@ return(s2 - s);
  */
 TimeType ae2_main(char *fname, char *skip_start, char *skip_end)
 {
-int i;
+unsigned int i;
 int match_idx;
 struct Node *n;
 struct symbol *s;
@@ -528,8 +536,8 @@ missing = calloc_2(1, (GLOBALS->ae2_num_aliases + 7 + 1) / 8); /* + 1 to mirror
 for(i=0;i<GLOBALS->ae2_num_aliases;i++)
 	{
 	unsigned long numTerms;
-        int idx = i+1;
-	int ii;
+        unsigned int idx = i+1;
+	unsigned int ii;
 	int midx, mbit;
 	int mcnt;
 
@@ -632,12 +640,12 @@ if(!GLOBALS->hier_was_explicitly_set)    /* set default hierarchy split char */
         }
 
 match_idx = 0;
-for(i=0;i<GLOBALS->numfacs;i++)
+for(i=0;i<(unsigned int)GLOBALS->numfacs;i++)
         {
-	char *str;	
+	char *str;
         int idx;
 	int typ;
-	unsigned long len, clen;
+	long len, clen;
 	int row_iter, mx_row, mx_row_adjusted;
 
 #ifdef AET2_ALIASDB_IS_PRESENT
@@ -720,7 +728,7 @@ for(i=0;i<GLOBALS->numfacs;i++)
 		s = &monolithic_sym[match_idx];
 	        symadd_name_exists_sym_exists(s, str,0);
 		}
-		
+
         mx_row = (GLOBALS->ae2_fr[match_idx].row < 1) ? 1 : GLOBALS->ae2_fr[match_idx].row;
 	mx_row_adjusted = (mx_row < 2) ? 0 : mx_row;
         n=&monolithic_node[mono_row_offset];
@@ -759,7 +767,7 @@ for(i=0;i<GLOBALS->numfacs;i++)
 #endif
 			n[row_iter].extvals = 1;
 			}
-                 
+
 	        n[row_iter].head.time=-1;        /* mark 1st node as negative time */
 	        n[row_iter].head.v.h_val=AN_X;
 		}
@@ -780,7 +788,7 @@ GLOBALS->facs=(struct symbol **)malloc_2(GLOBALS->numfacs*sizeof(struct symbol *
 
 if(GLOBALS->fast_tree_sort)
 	{
-	for(i=0;i<GLOBALS->numfacs;i++)
+	for(i=0;i<(unsigned int)GLOBALS->numfacs;i++)
 		{
 		GLOBALS->facs[i]=&monolithic_sym[i];
 		}
@@ -788,9 +796,9 @@ if(GLOBALS->fast_tree_sort)
 /* SPLASH */                            splash_sync(3, 5);
 	fprintf(stderr, AET2_RDLOAD"Building facility hierarchy tree.\n");
 
-	init_tree();		
+	init_tree();
 
-	for(i=0;i<GLOBALS->numfacs;i++)	
+	for(i=0;i<(unsigned int)GLOBALS->numfacs;i++)
 		{
 		int was_packed = HIER_DEPACK_STATIC; /* no need to free_2() afterward then */
 		char *sb = hier_decompress_flagged(GLOBALS->facs[i]->name, &was_packed);
@@ -809,47 +817,47 @@ if(GLOBALS->fast_tree_sort)
 	}
 	else
 	{
-	for(i=0;i<GLOBALS->numfacs;i++)
+	for(i=0;i<(unsigned int)GLOBALS->numfacs;i++)
 		{
 #ifdef WAVE_HIERFIX
 		char *subst;
-		char ch;	
+		char ch;
 #endif
 		GLOBALS->facs[i]=&monolithic_sym[i];
 #ifdef WAVE_HIERFIX
 		while((ch=(*subst)))
-			{	
+			{
 			if(ch==GLOBALS->hier_delimeter) { *subst=VCDNAM_HIERSORT; }	/* forces sort at hier boundaries */
 			subst++;
 			}
 #endif
 		}
-	
+
 /* SPLASH */                            splash_sync(3, 5);
 	fprintf(stderr, AET2_RDLOAD"Sorting facilities at hierarchy boundaries.\n");
 	wave_heapsort(GLOBALS->facs,GLOBALS->numfacs);
-	
+
 #ifdef WAVE_HIERFIX
 	for(i=0;i<GLOBALS->numfacs;i++)
 		{
 		char *subst, ch;
-	
+
 		subst=GLOBALS->facs[i]->name;
 		while((ch=(*subst)))
-			{	
+			{
 			if(ch==VCDNAM_HIERSORT) { *subst=GLOBALS->hier_delimeter; }	/* restore back to normal */
 			subst++;
 			}
 		}
-#endif	
+#endif
 
 	GLOBALS->facs_are_sorted=1;
 
 /* SPLASH */                            splash_sync(4, 5);
 	fprintf(stderr, AET2_RDLOAD"Building facility hierarchy tree.\n");
 
-	init_tree();		
-	for(i=0;i<GLOBALS->numfacs;i++)	
+	init_tree();
+	for(i=0;i<(unsigned int)GLOBALS->numfacs;i++)
 		{
 		build_tree_from_name(GLOBALS->facs[i]->name, i);
 		}
@@ -904,20 +912,20 @@ if(skip_start || skip_end)
 			{
 			if(GLOBALS->ae2_time_xlate[lim_idx - first_cycle] <= GLOBALS->min_time)
 				{
-				GLOBALS->ae2_start_limit_cyc = lim_idx;			
+				GLOBALS->ae2_start_limit_cyc = lim_idx;
 				}
-	
+
 			if(GLOBALS->ae2_time_xlate[lim_idx - first_cycle] >= GLOBALS->min_time)
 				{
 				break;
 				}
 			}
-	
+
 		for(; lim_idx <= last_cycle; lim_idx++)
 			{
 			if(GLOBALS->ae2_time_xlate[lim_idx - first_cycle] >= GLOBALS->max_time)
 				{
-				GLOBALS->ae2_end_limit_cyc = lim_idx;			
+				GLOBALS->ae2_end_limit_cyc = lim_idx;
 				break;
 				}
 			}
@@ -950,7 +958,7 @@ if(busycnt==WAVE_BUSY_ITER)
 
 /* fprintf(stderr, "%lld %d %d %s\n", *tim, *facidx, row, *value); */
 
-if(f->length>1)        
+if(f->length>1)
         {
         htemp->v.h_vector = (char *)malloc_2(f->length);
 	memcpy(htemp->v.h_vector, *value, f->length);
@@ -1001,17 +1009,17 @@ char buf[AE2_MAXFACLEN+1];
 
 autofacs = calloc_2(GLOBALS->numfacs, sizeof(struct ae2_ncycle_autosort));
 
-for(i=0;i<GLOBALS->numfacs;i++)
+for(i=0;i<(unsigned int)GLOBALS->numfacs;i++)
 	{
 	if(aet2_rd_get_fac_process_mask(i))
 		{
-		int nr = ae2_read_symbol_rows_2(GLOBALS->ae2,GLOBALS->ae2_fr[i].s);
+		unsigned int nr = ae2_read_symbol_rows_2(GLOBALS->ae2,GLOBALS->ae2_fr[i].s);
 		if(!nr) nr = 1;
 		for(r=0;r<nr;r++)
 			{
 			nptr np = GLOBALS->ae2_lx2_table[i][r].np;
 			np->mv.value = calloc_2(1, GLOBALS->ae2_fr[i].length+1);
-			}		
+			}
 		}
 	}
 
@@ -1031,7 +1039,7 @@ for(j=0;j<GLOBALS->ae2_num_sections;j++)
 
 	autosort = calloc_2(ecyc - cyc + 1, sizeof(struct ae2_ncycle_autosort *));
 
-	for(i=0;i<GLOBALS->numfacs;i++)
+	for(i=0;i<(unsigned int)GLOBALS->numfacs;i++)
 		{
 		if(aet2_rd_get_fac_process_mask(i))
 			{
@@ -1040,7 +1048,7 @@ for(j=0;j<GLOBALS->ae2_num_sections;j++)
 			if(nr<2)
 				{
 				nptr np = GLOBALS->ae2_lx2_table[i][0].np;
-	
+
 				ae2_read_value_2(GLOBALS->ae2, GLOBALS->ae2_fr+i, cyc, buf);
 				if(strcmp(np->mv.value, buf))
 					{
@@ -1053,16 +1061,16 @@ for(j=0;j<GLOBALS->ae2_num_sections;j++)
 				unsigned long sf = ae2_read_symbol_sparse_flag(GLOBALS->ae2, GLOBALS->ae2_fr[i].s);
 				if(sf)
 					{
-					int rows = ae2_read_num_sparse_rows(GLOBALS->ae2, GLOBALS->ae2_fr[i].s, cyc);
+					unsigned int rows = ae2_read_num_sparse_rows(GLOBALS->ae2, GLOBALS->ae2_fr[i].s, cyc);
 					if(rows)
 						{
 			                        for(r=1;r<rows+1;r++)
 			                                {
-							nptr np; 
+							nptr np;
 			                                uint64_t row = ae2_read_ith_sparse_row(GLOBALS->ae2, GLOBALS->ae2_fr[i].s, cyc, r);
-	
+
 			                                GLOBALS->ae2_fr[i].row = row;
-	
+
 							np = GLOBALS->ae2_lx2_table[i][row].np;
 			                                ae2_read_value_2(GLOBALS->ae2, GLOBALS->ae2_fr+i, cyc, buf);
 							if(strcmp(np->mv.value, buf))
@@ -1075,16 +1083,16 @@ for(j=0;j<GLOBALS->ae2_num_sections;j++)
 					}
 					else
 					{
-					int rows = ae2_read_symbol_rows_2(GLOBALS->ae2, GLOBALS->ae2_fr[i].s);
+					unsigned int rows = ae2_read_symbol_rows_2(GLOBALS->ae2, GLOBALS->ae2_fr[i].s);
 					if(rows)
 						{
 			                        for(r=0;r<rows;r++)
 			                                {
-							nptr np; 
+							nptr np;
 			                                uint64_t row = r;
-	
+
 			                                GLOBALS->ae2_fr[i].row = row;
-	
+
 							np = GLOBALS->ae2_lx2_table[i][row].np;
 			                                ae2_read_value_2(GLOBALS->ae2, GLOBALS->ae2_fr+i, cyc, buf);
 							if(strcmp(np->mv.value, buf))
@@ -1101,7 +1109,7 @@ for(j=0;j<GLOBALS->ae2_num_sections;j++)
 
 	deadlist=NULL;
 
-	for(i=0;i<GLOBALS->numfacs;i++)
+	for(i=0;i<(unsigned int)GLOBALS->numfacs;i++)
 		{
 		uint64_t ncyc;
 		nptr np;
@@ -1120,7 +1128,7 @@ for(j=0;j<GLOBALS->ae2_num_sections;j++)
 			unsigned long sf = ae2_read_symbol_sparse_flag(GLOBALS->ae2, GLOBALS->ae2_fr[i].s);
 			if(sf)
 				{
-				int rows = ae2_read_num_sparse_rows(GLOBALS->ae2, GLOBALS->ae2_fr[i].s, cyc);
+				unsigned int rows = ae2_read_num_sparse_rows(GLOBALS->ae2, GLOBALS->ae2_fr[i].s, cyc);
 				uint64_t mxcyc = end_cycle+1;
 
 	                        for(r=1;r<rows+1;r++)
@@ -1131,7 +1139,7 @@ for(j=0;j<GLOBALS->ae2_num_sections;j++)
 	                                GLOBALS->ae2_fr[i].row = row;
 					/* np = GLOBALS->ae2_lx2_table[i][row].np; */
 					ncyc =	ae2_read_next_value_2(GLOBALS->ae2, GLOBALS->ae2_fr+i, cyc, buf);
-	
+
 					if((ncyc > cyc) && (ncyc < mxcyc)) mxcyc = ncyc;
 					}
 
@@ -1146,7 +1154,7 @@ for(j=0;j<GLOBALS->ae2_num_sections;j++)
 				}
 				else
 				{
-				int rows = ae2_read_symbol_rows_2(GLOBALS->ae2, GLOBALS->ae2_fr[i].s);
+				unsigned int rows = ae2_read_symbol_rows_2(GLOBALS->ae2, GLOBALS->ae2_fr[i].s);
 				uint64_t mxcyc = end_cycle+1;
 
 	                        for(r=0;r<rows;r++)
@@ -1157,7 +1165,7 @@ for(j=0;j<GLOBALS->ae2_num_sections;j++)
 	                                GLOBALS->ae2_fr[i].row = row;
 					/* np = GLOBALS->ae2_lx2_table[i][row].np; */
 					ncyc =	ae2_read_next_value_2(GLOBALS->ae2, GLOBALS->ae2_fr+i, cyc, buf);
-	
+
 					if((ncyc > cyc) && (ncyc < mxcyc)) mxcyc = ncyc;
 					}
 
@@ -1176,9 +1184,9 @@ for(j=0;j<GLOBALS->ae2_num_sections;j++)
 			{
 			int offset = ncyc-cyc;
 			struct ae2_ncycle_autosort *t = autosort[offset];
-		
+
 			autofacs[i].next = t;
-			autosort[offset] = autofacs+i; 
+			autosort[offset] = autofacs+i;
 			}
 			else
 			{
@@ -1194,7 +1202,7 @@ for(j=0;j<GLOBALS->ae2_num_sections;j++)
 		struct ae2_ncycle_autosort *t = autosort[offset];
 
 		if(step_cyc > end_cycle) break;
-	
+
 		if(t)
 			{
 			while(t)
@@ -1202,8 +1210,8 @@ for(j=0;j<GLOBALS->ae2_num_sections;j++)
 				uint64_t ncyc;
 				struct ae2_ncycle_autosort *tn = t->next;
 				nptr np;
-				int nr;	
-	
+				int nr;
+
 				i = t-autofacs;
 				nr = ae2_read_symbol_rows_2(GLOBALS->ae2,GLOBALS->ae2_fr[i].s);
 
@@ -1212,7 +1220,7 @@ for(j=0;j<GLOBALS->ae2_num_sections;j++)
 					np = GLOBALS->ae2_lx2_table[i][0].np;
 
 					ae2_callback(&step_cyc, &i, &np->mv.value, 0);
-		
+
 					ncyc = ae2_read_next_value_2(GLOBALS->ae2, GLOBALS->ae2_fr+i, step_cyc, np->mv.value);
 					}
 					else
@@ -1220,12 +1228,12 @@ for(j=0;j<GLOBALS->ae2_num_sections;j++)
 					unsigned long sf = ae2_read_symbol_sparse_flag(GLOBALS->ae2, GLOBALS->ae2_fr[i].s);
 					if(sf)
 						{
-						int rows = ae2_read_num_sparse_rows(GLOBALS->ae2, GLOBALS->ae2_fr[i].s, step_cyc);
+						unsigned int rows = ae2_read_num_sparse_rows(GLOBALS->ae2, GLOBALS->ae2_fr[i].s, step_cyc);
 						uint64_t mxcyc = end_cycle+1;
 
 			                        for(r=1;r<rows+1;r++)
 		        	                        {
-							nptr npr; 
+							nptr npr;
 			                                uint64_t row = ae2_read_ith_sparse_row(GLOBALS->ae2, GLOBALS->ae2_fr[i].s, step_cyc, r);
 
 			                                GLOBALS->ae2_fr[i].row = row;
@@ -1241,7 +1249,7 @@ for(j=0;j<GLOBALS->ae2_num_sections;j++)
 							ncyc =	ae2_read_next_value_2(GLOBALS->ae2, GLOBALS->ae2_fr+i, step_cyc, buf);
 							if((ncyc > step_cyc) && (ncyc < mxcyc)) mxcyc = ncyc;
 							}
-	
+
 						if(mxcyc != (end_cycle+1))
 							{
 							ncyc = mxcyc;
@@ -1253,12 +1261,12 @@ for(j=0;j<GLOBALS->ae2_num_sections;j++)
 						}
 						else
 						{
-						int rows = ae2_read_symbol_rows_2(GLOBALS->ae2, GLOBALS->ae2_fr[i].s);
+						unsigned int rows = ae2_read_symbol_rows_2(GLOBALS->ae2, GLOBALS->ae2_fr[i].s);
 						uint64_t mxcyc = end_cycle+1;
 
 			                        for(r=0;r<rows;r++)
 		        	                        {
-							nptr npr; 
+							nptr npr;
 			                                uint64_t row = r;
 
 			                                GLOBALS->ae2_fr[i].row = row;
@@ -1274,7 +1282,7 @@ for(j=0;j<GLOBALS->ae2_num_sections;j++)
 							ncyc =	ae2_read_next_value_2(GLOBALS->ae2, GLOBALS->ae2_fr+i, step_cyc, buf);
 							if((ncyc > step_cyc) && (ncyc < mxcyc)) mxcyc = ncyc;
 							}
-	
+
 						if(mxcyc != (end_cycle+1))
 							{
 							ncyc = mxcyc;
@@ -1285,14 +1293,14 @@ for(j=0;j<GLOBALS->ae2_num_sections;j++)
 							}
 						}
 					}
-		
+
 				if(ncyc!=step_cyc)
 					{
 					int offset2 = ncyc-cyc;
 					struct ae2_ncycle_autosort *ta = autosort[offset2];
-				
+
 					autofacs[i].next = ta;
-					autosort[offset2] = autofacs+i; 
+					autosort[offset2] = autofacs+i;
 					}
 					else
 					{
@@ -1309,18 +1317,18 @@ for(j=0;j<GLOBALS->ae2_num_sections;j++)
 	}
 
 
-for(i=0;i<GLOBALS->numfacs;i++)
+for(i=0;i<(unsigned int)GLOBALS->numfacs;i++)
 	{
 	if(aet2_rd_get_fac_process_mask(i))
 		{
-		int nr = ae2_read_symbol_rows_2(GLOBALS->ae2,GLOBALS->ae2_fr[i].s);
+		unsigned int nr = ae2_read_symbol_rows_2(GLOBALS->ae2,GLOBALS->ae2_fr[i].s);
 		if(!nr) nr = 1;
 		for(r=0;r<nr;r++)
 			{
 			nptr np = GLOBALS->ae2_lx2_table[i][r].np;
 			free_2(np->mv.value);
 			np->mv.value = NULL;
-			}		
+			}
 		}
 	}
 
@@ -1329,8 +1337,8 @@ return(0);
 }
 
 
-/* 
- * actually import an ae2 trace but don't do it if it's already been imported 
+/*
+ * actually import an ae2 trace but don't do it if it's already been imported
  */
 void import_ae2_trace(nptr np)
 {
@@ -1412,7 +1420,7 @@ for(r = 0; r < nr; r++)
 		htemp->v.h_val = AN_X;		/* x */
 		}
 	htemp->time = MAX_HISTENT_TIME-1;
-	htemp->next = histent_tail;			
+	htemp->next = histent_tail;
 
 	if(GLOBALS->ae2_lx2_table[txidx][r].histent_curr)
 		{
@@ -1433,13 +1441,13 @@ for(r = 0; r < nr; r++)
 
                 {
                 struct HistEnt *htemp2 = histent_calloc();
-                htemp2->time = -1;  
+                htemp2->time = -1;
                 if(len>1)
                 	{
                         htemp2->v.h_vector = htemp->v.h_vector;
                         }
                         else
-                        {  
+                        {
                         htemp2->v.h_val = htemp->v.h_val;
                         }
 		htemp2->next = htemp;
@@ -1457,7 +1465,7 @@ for(r = 0; r < nr; r++)
 }
 
 
-/* 
+/*
  * pre-import many traces at once so function above doesn't have to iterate...
  */
 void ae2_set_fac_process_mask(nptr np)
@@ -1533,7 +1541,7 @@ for(txidx=0;txidx<GLOBALS->numfacs;txidx++)
 				htemp->v.h_val = AN_Z;		/* z */
 				}
 			htemp->time = MAX_HISTENT_TIME;
-			
+
 			htemp = histent_calloc();
 			if(len>1)
 				{
@@ -1545,8 +1553,8 @@ for(txidx=0;txidx<GLOBALS->numfacs;txidx++)
 				htemp->v.h_val = AN_X;		/* x */
 				}
 			htemp->time = MAX_HISTENT_TIME-1;
-			htemp->next = histent_tail;			
-	
+			htemp->next = histent_tail;
+
 			if(GLOBALS->ae2_lx2_table[txidx][r].histent_curr)
 				{
 				GLOBALS->ae2_lx2_table[txidx][r].histent_curr->next = htemp;
@@ -1556,13 +1564,13 @@ for(txidx=0;txidx<GLOBALS->numfacs;txidx++)
 
                         {
                         struct HistEnt *htemp2 = histent_calloc();
-                        htemp2->time = -1;  
+                        htemp2->time = -1;
                         if(len>1)
                                 {
                                 htemp2->v.h_vector = htemp->v.h_vector;
                                 }
                                 else
-                                {  
+                                {
                                 htemp2->v.h_val = htemp->v.h_val;
                                 }
                         htemp2->next = htemp;
