@@ -1,4 +1,4 @@
-/* 
+/*
  * Copyright (c) Tony Bybell 1999-2013.
  *
  * This program is free software; you can redistribute it and/or
@@ -13,6 +13,7 @@
 #include "gtk12compat.h"
 #include "menu.h"
 #include "debug.h"
+#include <cocoa_misc.h>
 #include <string.h>
 
 #ifdef MAC_INTEGRATION
@@ -23,6 +24,10 @@
 #ifndef WAVE_MAC_USE_ENTRY
 static gint keypress_local(GtkWidget *widget, GdkEventKey *event, gpointer data)
 {
+(void)widget;
+(void)event;
+(void)data;
+
 if(GLOBALS->window_entry_c_1)
 	{
 	gdk_window_raise(GLOBALS->window_entry_c_1->window);
@@ -35,6 +40,9 @@ return(FALSE);
 #ifndef WAVE_MAC_USE_ENTRY
 static void enter_callback(GtkWidget *widget, GtkWidget *nothing)
 {
+(void)widget;
+(void)nothing;
+
   G_CONST_RETURN gchar *entry_text;
   int len;
   entry_text = gtk_entry_get_text(GTK_ENTRY(GLOBALS->entry_entry_c_1));
@@ -52,6 +60,9 @@ static void enter_callback(GtkWidget *widget, GtkWidget *nothing)
 
 static void destroy_callback(GtkWidget *widget, GtkWidget *nothing)
 {
+(void)widget;
+(void)nothing;
+
   DEBUG(printf("Entry Cancel\n"));
   GLOBALS->entrybox_text=NULL;
   wave_gtk_grab_remove(GLOBALS->window_entry_c_1);
@@ -62,9 +73,11 @@ static void destroy_callback(GtkWidget *widget, GtkWidget *nothing)
 
 void entrybox(char *title, int width, char *dflt_text, char *comment, int maxch, GtkSignalFunc func)
 {
+#ifndef WAVE_MAC_USE_ENTRY
     GtkWidget *vbox, *hbox;
     GtkWidget *button1, *button2;
     int height = (comment) ? 75 : 60;
+#endif
 
     GLOBALS->cleanup_entry_c_1=func;
 
@@ -93,7 +106,7 @@ void entrybox(char *title, int width, char *dflt_text, char *comment, int maxch,
 #ifdef WAVE_MAC_USE_ENTRY
 {
 char *out_text_entry = NULL;
-int rc = entrybox_req_bridge(title, width, dflt_text, comment, maxch, &out_text_entry);
+entrybox_req_bridge(title, width, dflt_text, comment, maxch, &out_text_entry);
 if(out_text_entry)
 	{
 	int len=strlen(out_text_entry);
