@@ -1,5 +1,5 @@
 /*
- * Copyright (c) Tony Bybell 2009-2014.
+ * Copyright (c) Tony Bybell 2009-2015.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -72,6 +72,90 @@ exit(255);
 
 #else
 
+/******************************************************************/
+
+/*
+ * reverse equality mem compare
+ */
+static int memrevcmp(int i, const char *s1, const char *s2)
+{
+i--;
+for(;i>=0;i--)
+        {
+        if(s1[i] != s2[i]) break;
+        }
+
+return(i+1);
+}
+
+
+
+/*
+ * fast itoa for decimal numbers
+ */
+static char* itoa_2(int value, char* result)
+{
+char* ptr = result, *ptr1 = result, tmp_char;
+int tmp_value;
+
+do {
+        tmp_value = value;
+        value /= 10;
+        *ptr++ = "9876543210123456789" [9 + (tmp_value - value * 10)];
+} while ( value );
+
+if (tmp_value < 0) *ptr++ = '-';
+result = ptr;
+*ptr-- = '\0';
+while(ptr1 < ptr) {
+        tmp_char = *ptr;
+        *ptr--= *ptr1;
+        *ptr1++ = tmp_char;
+}
+return(result);
+}
+
+
+/*
+ * preformatted sprintf statements which remove parsing latency
+ */
+static int sprintf_2_sd(char *s, char *c, int d)
+{
+char *s2 = s;
+
+while(*c)
+        {
+        *(s2++) = *(c++);
+        }
+*(s2++) = '[';
+s2 = itoa_2(d, s2);
+*(s2++) = ']';
+*s2 = 0;
+
+return(s2 - s);
+}
+
+
+static int sprintf_2_sdd(char *s, char *c, int d, int d2)
+{
+char *s2 = s;
+
+while(*c)
+        {
+        *(s2++) = *(c++);
+        }
+*(s2++) = '[';
+s2 = itoa_2(d, s2);
+*(s2++) = ':';
+s2 = itoa_2(d2, s2);
+*(s2++) = ']';
+*s2 = 0;
+
+return(s2 - s);
+}
+
+/******************************************************************/
+
 #ifndef WAVE_FSDB_READER_IS_PRESENT
 static int last_modification_check(void)
 {
@@ -187,8 +271,15 @@ for(;;)
 			char *vtyp_nam;
 			char *cpyto;
 			char *pntd;
+			char *typ_src = pnt;
+			char *typ_dst = typ;
 
-			sscanf(rc + 5, "%s", typ);
+			/* following code replaces: sscanf(rc + 5, "%s", typ) */
+			while(*typ_src && !isspace(*typ_src))
+				{
+				*(typ_dst++) = *(typ_src++);
+				}
+			*typ_dst = 0;
 
 			while(*pnt)
 				{
@@ -233,9 +324,28 @@ for(;;)
 			if(last_l)
 				{
 				unsigned int l, r;
-				char s1[32];
+				/* char s1[32]; */
 				unsigned int d2;
-				sscanf(last_l+2, "%u r:%u %s %u", &l, &r, s1, &d2);
+				/* sscanf(last_l+2, "%u r:%u %s %u", &l, &r, s1, &d2); */
+					
+				char *ps = last_l+2;
+				char *l_pnt, *r_pnt, *d2_pnt;
+
+				while(*ps &&  isspace(*ps)) { ps++; }
+				l_pnt = ps;
+				while(*ps && !isspace(*ps)) { ps++; }
+				while(*ps &&  isspace(*ps)) { ps++; }
+				r_pnt = ps;					
+				while(*ps && !isspace(*ps)) { ps++; }
+				while(*ps &&  isspace(*ps)) { ps++; }
+				/* s1_pnt = ps;	*/
+				while(*ps && !isspace(*ps)) { ps++; }
+				while(*ps &&  isspace(*ps)) { ps++; }
+				d2_pnt = ps;
+
+				l = atoi(l_pnt);
+				r = atoi(r_pnt+2);
+				d2 = atoi(d2_pnt);
 
 				GLOBALS->extload_idcodes[i] = d2;
 				if(GLOBALS->extload_inv_idcodes[d2] == 0) GLOBALS->extload_inv_idcodes[d2] = i+1; /* root alias */
@@ -524,6 +634,7 @@ char *str;
 struct fac *f;
 char *fnam;
 int flen;
+int longest_nam_candidate = 0;
 
 i = GLOBALS->extload_i;
 
@@ -535,22 +646,25 @@ if(i<0)
 
 	if(GLOBALS->extload_hlen)
 		{
-		GLOBALS->extload_namecache[0]=malloc_2(GLOBALS->extload_hlen+1+flen+1);
-		strcpy(GLOBALS->extload_namecache[0], GLOBALS->fst_scope_name);
-		*(GLOBALS->extload_namecache[0]+GLOBALS->extload_hlen) = '.';
-		strcpy(GLOBALS->extload_namecache[0]+GLOBALS->extload_hlen+1, fnam);
+		GLOBALS->extload_namecache[0 & F_NAME_MODULUS]=malloc_2(GLOBALS->extload_namecache_max[0 & F_NAME_MODULUS]=GLOBALS->extload_hlen+1+flen+1);
+		memcpy(GLOBALS->extload_namecache[0 & F_NAME_MODULUS], GLOBALS->fst_scope_name, GLOBALS->extload_hlen);
+		*(GLOBALS->extload_namecache[0 & F_NAME_MODULUS]+GLOBALS->extload_hlen) = '.';
+		strcpy(GLOBALS->extload_namecache[0 & F_NAME_MODULUS]+GLOBALS->extload_hlen+1, fnam);
+		GLOBALS->extload_namecache_lens[0 & F_NAME_MODULUS]=GLOBALS->extload_hlen + 1 + flen;
 		}
 	else
 		{
-		GLOBALS->extload_namecache[0]=malloc_2(flen+1);
-		strcpy(GLOBALS->extload_namecache[0], fnam);
+		GLOBALS->extload_namecache[0 & F_NAME_MODULUS]=malloc_2(GLOBALS->extload_namecache_max[0 & F_NAME_MODULUS]=flen+1);
+		strcpy(GLOBALS->extload_namecache[0 & F_NAME_MODULUS], fnam);
+		GLOBALS->extload_namecache_lens[0 & F_NAME_MODULUS] = flen;
 		}
 #else
 	fnam = get_varname(&GLOBALS->extload_vt_prev, &GLOBALS->extload_vd_prev, 0);
 	flen = strlen(fnam);
 
-	GLOBALS->extload_namecache[0]=malloc_2(flen+1);
-	strcpy(GLOBALS->extload_namecache[0], fnam);
+	GLOBALS->extload_namecache[0 & F_NAME_MODULUS]=malloc_2(GLOBALS->extload_namecache_max[0 & F_NAME_MODULUS]=flen+1);
+	strcpy(GLOBALS->extload_namecache[0 & F_NAME_MODULUS], fnam);
+	GLOBALS->extload_namecache_lens[0 & F_NAME_MODULUS] = flen;
 #endif
 	}
 else
@@ -565,37 +679,59 @@ else
 
 		if(GLOBALS->extload_hlen)
 			{
-			GLOBALS->extload_namecache[i+1]=malloc_2(GLOBALS->extload_hlen+1+flen+1);
-			strcpy(GLOBALS->extload_namecache[i+1], GLOBALS->fst_scope_name);
-			*(GLOBALS->extload_namecache[i+1]+GLOBALS->extload_hlen) = '.';
-			strcpy(GLOBALS->extload_namecache[i+1]+GLOBALS->extload_hlen+1, fnam);
+			if(GLOBALS->extload_namecache_max[(i+1)&F_NAME_MODULUS] < (GLOBALS->extload_hlen+1+flen+1))
+				{
+				if(GLOBALS->extload_namecache[(i+1)&F_NAME_MODULUS]) free_2(GLOBALS->extload_namecache[(i+1)&F_NAME_MODULUS]);
+				GLOBALS->extload_namecache[(i+1)&F_NAME_MODULUS]=malloc_2(GLOBALS->extload_namecache_max[(i+1)&F_NAME_MODULUS] = GLOBALS->extload_hlen+1+flen+1);
+				}
+
+			memcpy(GLOBALS->extload_namecache[(i+1)&F_NAME_MODULUS], GLOBALS->fst_scope_name, GLOBALS->extload_hlen);
+			*(GLOBALS->extload_namecache[(i+1)&F_NAME_MODULUS]+GLOBALS->extload_hlen) = '.';
+			strcpy(GLOBALS->extload_namecache[(i+1)&F_NAME_MODULUS]+GLOBALS->extload_hlen+1, fnam);
+			GLOBALS->extload_namecache_lens[(i+1)&F_NAME_MODULUS] = GLOBALS->extload_hlen + 1 + flen;
 			}
 		else
 			{
-			GLOBALS->extload_namecache[i+1]=malloc_2(flen+1);
-			strcpy(GLOBALS->extload_namecache[i+1], fnam);
+			if(GLOBALS->extload_namecache_max[(i+1)&F_NAME_MODULUS] < (flen+1))
+				{
+				if(GLOBALS->extload_namecache[(i+1)&F_NAME_MODULUS])free_2(GLOBALS->extload_namecache[(i+1)&F_NAME_MODULUS]);
+				GLOBALS->extload_namecache[(i+1)&F_NAME_MODULUS]=malloc_2(GLOBALS->extload_namecache_max[(i+1)&F_NAME_MODULUS] = flen+1);
+				}
+			strcpy(GLOBALS->extload_namecache[(i+1)&F_NAME_MODULUS], fnam);
+			GLOBALS->extload_namecache_lens[(i+1)&F_NAME_MODULUS] = flen;
 			}
 #else
 		fnam = get_varname(&GLOBALS->extload_vt_prev, &GLOBALS->extload_vd_prev, i+1);
 		flen = strlen(fnam);
 
-		GLOBALS->extload_namecache[i+1]=malloc_2(flen+1);
-		strcpy(GLOBALS->extload_namecache[i+1], fnam);
+		if(GLOBALS->extload_namecache_max[(i+1)&F_NAME_MODULUS] < (flen+1))
+			{
+			GLOBALS->extload_namecache[(i+1)&F_NAME_MODULUS]=malloc_2(GLOBALS->extload_namecache_max[(i+1)&F_NAME_MODULUS] = flen+1);
+			}
+		strcpy(GLOBALS->extload_namecache[(i+1)&F_NAME_MODULUS], fnam);
+			GLOBALS->extload_namecache_lens[(i+1)&F_NAME_MODULUS] = flen;
 #endif
 		}
 
-	if(i>1)
-		{
-		free_2(GLOBALS->extload_namecache[i-2]);
-		GLOBALS->extload_namecache[i-2] = NULL;
-		}
-
 	f=GLOBALS->mvlfacs_vzt_c_3+i;
 
 	if((f->len>1)&& (!(f->flags&(VZT_RD_SYM_F_INTEGER|VZT_RD_SYM_F_DOUBLE|VZT_RD_SYM_F_STRING))) )
 		{
-		int len=sprintf(buf, "%s[%d:%d]", GLOBALS->extload_namecache[i],GLOBALS->extload_node_block[i].msi, GLOBALS->extload_node_block[i].lsi);
-		str=malloc_2(len+1);
+		int len=sprintf_2_sdd(buf, GLOBALS->extload_namecache[i&F_NAME_MODULUS],GLOBALS->extload_node_block[i].msi, GLOBALS->extload_node_block[i].lsi);
+		longest_nam_candidate = len;
+
+                if(!GLOBALS->do_hier_compress)
+                        {
+                        str=malloc_2(len+1);
+                        }   
+                        else
+                        {
+                        if(len > GLOBALS->f_name_build_buf_len)
+                                {
+                                free_2(GLOBALS->f_name_build_buf); GLOBALS->f_name_build_buf = malloc_2((GLOBALS->f_name_build_buf_len=len)+1);
+                                }
+                        str = GLOBALS->f_name_build_buf;
+                        }
 
 		if(!GLOBALS->alt_hier_delimeter)
 			{
@@ -611,14 +747,28 @@ else
 		}
 	else if (
 			((f->len==1)&&(!(f->flags&(VZT_RD_SYM_F_INTEGER|VZT_RD_SYM_F_DOUBLE|VZT_RD_SYM_F_STRING)))&&
-			((i!=GLOBALS->numfacs-1)&&(!strcmp(GLOBALS->extload_namecache[i], GLOBALS->extload_namecache[i+1]))))
+			((i!=GLOBALS->numfacs-1)&&(GLOBALS->extload_namecache_lens[i&F_NAME_MODULUS]==GLOBALS->extload_namecache_lens[(i+1)&F_NAME_MODULUS])&&(!memrevcmp(GLOBALS->extload_namecache_lens[i&F_NAME_MODULUS],GLOBALS->extload_namecache[i&F_NAME_MODULUS], GLOBALS->extload_namecache[(i+1)&F_NAME_MODULUS]))))
 			||
-			(((i!=0)&&(!strcmp(GLOBALS->extload_namecache[i], GLOBALS->extload_namecache[i-1]))) &&
+			(((i!=0)&&(GLOBALS->extload_namecache_lens[i&F_NAME_MODULUS]==GLOBALS->extload_namecache_lens[(i-1)&F_NAME_MODULUS])&&(!memrevcmp(GLOBALS->extload_namecache_lens[i&F_NAME_MODULUS], GLOBALS->extload_namecache[i&F_NAME_MODULUS], GLOBALS->extload_namecache[(i-1)&F_NAME_MODULUS]))) &&
 			(GLOBALS->extload_node_block[i].msi!=-1)&&(GLOBALS->extload_node_block[i].lsi!=-1))
 		)
 		{
-		int len = sprintf(buf, "%s[%d]", GLOBALS->extload_namecache[i],GLOBALS->extload_node_block[i].msi);
-		str=malloc_2(len+1);
+		int len = sprintf_2_sd(buf, GLOBALS->extload_namecache[i&F_NAME_MODULUS],GLOBALS->extload_node_block[i].msi);
+		longest_nam_candidate = len;
+
+                if(!GLOBALS->do_hier_compress)
+                        {
+                        str=malloc_2(len+1);
+                        }
+                        else
+                        {
+                        if(len > GLOBALS->f_name_build_buf_len)
+                                {
+                                free_2(GLOBALS->f_name_build_buf); GLOBALS->f_name_build_buf = malloc_2((GLOBALS->f_name_build_buf_len=len)+1);
+                                }
+                        str = GLOBALS->f_name_build_buf;
+                        }
+
 		if(!GLOBALS->alt_hier_delimeter)
 			{
 			strcpy(str, buf);
@@ -629,7 +779,7 @@ else
 			}
 		s=&GLOBALS->extload_sym_block[i];
 	        symadd_name_exists_sym_exists(s,str,0);
-		if((GLOBALS->extload_prevsym)&&(i>0)&&(!strcmp(GLOBALS->extload_namecache[i], GLOBALS->extload_namecache[i-1])))	/* allow chaining for search functions.. */
+		if((GLOBALS->extload_prevsym)&&(i>0)&&(GLOBALS->extload_namecache_lens[i&F_NAME_MODULUS]==GLOBALS->extload_namecache_lens[(i-1)&F_NAME_MODULUS])&&(!memrevcmp(GLOBALS->extload_namecache_lens[i&F_NAME_MODULUS], GLOBALS->extload_namecache[i&F_NAME_MODULUS], GLOBALS->extload_namecache[(i-1)&F_NAME_MODULUS])))	/* allow chaining for search functions.. */
 			{
 			GLOBALS->extload_prevsym->vec_root = GLOBALS->extload_prevsymroot;
 			GLOBALS->extload_prevsym->vec_chain = s;
@@ -643,14 +793,29 @@ else
 		}
 		else
 		{
-		str=malloc_2(strlen(GLOBALS->extload_namecache[i])+1);
+		int len = GLOBALS->extload_namecache_lens[i&F_NAME_MODULUS];
+
+		longest_nam_candidate = len;
+                if(!GLOBALS->do_hier_compress)
+                        {
+                        str=malloc_2(len+1);
+                        }
+                        else
+                        {   
+                        if(len > GLOBALS->f_name_build_buf_len)
+                                {
+                                free_2(GLOBALS->f_name_build_buf); GLOBALS->f_name_build_buf = malloc_2((GLOBALS->f_name_build_buf_len=len)+1);
+                                }
+                        str = GLOBALS->f_name_build_buf;
+                        }
+
 		if(!GLOBALS->alt_hier_delimeter)
 			{
-			strcpy(str, GLOBALS->extload_namecache[i]);
+			strcpy(str, GLOBALS->extload_namecache[i&F_NAME_MODULUS]);
 			}
 			else
 			{
-			strcpy_vcdalt(str, GLOBALS->extload_namecache[i], GLOBALS->alt_hier_delimeter);
+			strcpy_vcdalt(str, GLOBALS->extload_namecache[i&F_NAME_MODULUS], GLOBALS->alt_hier_delimeter);
 			}
 		s=&GLOBALS->extload_sym_block[i];
 	        symadd_name_exists_sym_exists(s,str,0);
@@ -665,6 +830,20 @@ else
 		}
 
         n=&GLOBALS->extload_node_block[i];
+
+	if(longest_nam_candidate > GLOBALS->longestname) GLOBALS->longestname = longest_nam_candidate;
+
+        if(GLOBALS->do_hier_compress)
+                {
+                n->nname = compress_facility((unsigned char *)s->name, longest_nam_candidate);
+                /* free_2(s->name); ...removed as GLOBALS->f_name_build_buf is now used */
+                s->name = n->nname;
+                }
+                else
+                {
+                n->nname=s->name;
+                }
+
         n->nname=s->name;
         n->mv.mvlfac = GLOBALS->mvlfacs_vzt_c_3+i;
 	GLOBALS->mvlfacs_vzt_c_3[i].working_node = n;
@@ -965,12 +1144,25 @@ GLOBALS->max_time *= GLOBALS->time_scale;
 
 GLOBALS->mvlfacs_vzt_c_3=(struct fac *)calloc_2(GLOBALS->numfacs,sizeof(struct fac));
 GLOBALS->vzt_table_vzt_c_1=(struct lx2_entry *)calloc_2(GLOBALS->numfacs, sizeof(struct lx2_entry));
-GLOBALS->extload_namecache=(char **)calloc_2(GLOBALS->numfacs, sizeof(char *));
+GLOBALS->extload_namecache=(char **)calloc_2(F_NAME_MODULUS+1, sizeof(char *));
+GLOBALS->extload_namecache_max=(int *)calloc_2(F_NAME_MODULUS+1, sizeof(int));
+GLOBALS->extload_namecache_lens=(int *)calloc_2(F_NAME_MODULUS+1, sizeof(int));
 GLOBALS->extload_sym_block = (struct symbol *)calloc_2(GLOBALS->numfacs, sizeof(struct symbol));
 GLOBALS->extload_node_block=(struct Node *)calloc_2(GLOBALS->numfacs,sizeof(struct Node));
 GLOBALS->extload_idcodes=(unsigned int *)calloc_2(GLOBALS->numfacs, sizeof(unsigned int));
 GLOBALS->extload_inv_idcodes=(int *)calloc_2(max_idcode+1, sizeof(int));
 
+if(!GLOBALS->fast_tree_sort)
+        {
+        GLOBALS->do_hier_compress = 0;
+        }
+
+GLOBALS->f_name_build_buf_len = 128;
+GLOBALS->f_name_build_buf = malloc_2(GLOBALS->f_name_build_buf_len + 1);
+
+init_facility_pack();
+
+
 /* SPLASH */                            splash_sync(1, 5);
 
 #ifdef WAVE_FSDB_READER_IS_PRESENT
@@ -989,7 +1181,7 @@ process_extload_variable(NULL); /* flush out final cached variable */
 decorated_module_cleanup(); /* ...also now in gtk2_treesearch.c */
 iter_through_comp_name_table();
 
-for(i=0;((i<2)&&(i<GLOBALS->numfacs));i++)
+for(i=0;i<=F_NAME_MODULUS;i++)
 	{
 	if(GLOBALS->extload_namecache[i])
 		{
@@ -998,6 +1190,8 @@ for(i=0;((i<2)&&(i<GLOBALS->numfacs));i++)
 		}
 	}
 free_2(GLOBALS->extload_namecache); GLOBALS->extload_namecache = NULL;
+free_2(GLOBALS->extload_namecache_max); GLOBALS->extload_namecache_max = NULL;
+free_2(GLOBALS->extload_namecache_lens); GLOBALS->extload_namecache_lens = NULL;
 
 fstReaderClose(GLOBALS->extload_xc); /* corresponds to fstReaderOpenForUtilitiesOnly() */
 
@@ -1025,7 +1219,7 @@ while(get_varname(&GLOBALS->extload_vt_prev, NULL, -1)); /* read through end to
 decorated_module_cleanup(); /* ...also now in gtk2_treesearch.c */
 iter_through_comp_name_table();
 
-for(i=0;((i<2)&&(i<GLOBALS->numfacs));i++)
+for(i=0;i<=F_NAME_MODULUS;i++)
 	{
 	if(GLOBALS->extload_namecache[i])
 		{
@@ -1034,6 +1228,8 @@ for(i=0;((i<2)&&(i<GLOBALS->numfacs));i++)
 		}
 	}
 free_2(GLOBALS->extload_namecache); GLOBALS->extload_namecache = NULL;
+free_2(GLOBALS->extload_namecache_max); GLOBALS->extload_namecache_max = NULL;
+free_2(GLOBALS->extload_namecache_lens); GLOBALS->extload_namecache_lens = NULL;
 pclose(GLOBALS->extload);
 
 fstReaderClose(GLOBALS->extload_xc); /* corresponds to fstReaderOpenForUtilitiesOnly() */
@@ -1041,15 +1237,16 @@ fstReaderClose(GLOBALS->extload_xc); /* corresponds to fstReaderOpenForUtilities
 #endif
 
 /* SPLASH */                            splash_sync(2, 5);
+if(GLOBALS->f_name_build_buf) { free_2(GLOBALS->f_name_build_buf); GLOBALS->f_name_build_buf = NULL; }
+freeze_facility_pack();
+
 GLOBALS->facs=(struct symbol **)malloc_2(GLOBALS->numfacs*sizeof(struct symbol *));
 
 if(GLOBALS->fast_tree_sort)
         {
         for(i=0;i<GLOBALS->numfacs;i++)
                 {
-                int len;
                 GLOBALS->facs[i]=&GLOBALS->extload_sym_block[i];
-                if((len=strlen(GLOBALS->facs[i]->name))>GLOBALS->longestname) GLOBALS->longestname=len;
                 }
 
 /* SPLASH */                            splash_sync(3, 5);
@@ -1058,7 +1255,9 @@ if(GLOBALS->fast_tree_sort)
         init_tree();
         for(i=0;i<GLOBALS->numfacs;i++)
                 {
-		build_tree_from_name(GLOBALS->facs[i]->name, i);
+                int was_packed = HIER_DEPACK_STATIC; /* no need to free_2() afterward then */
+                char *sb = hier_decompress_flagged(GLOBALS->facs[i]->name, &was_packed);
+                build_tree_from_name(sb, i);
                 }
 /* SPLASH */                            splash_sync(4, 5);
         treegraft(&GLOBALS->treeroot);
@@ -1522,6 +1721,7 @@ if(GLOBALS->extload_inv_idcodes[txidx_in_trace] > 0)
 	if(!GLOBALS->extload_ffr_import_count)
 		{
 		fsdbReaderUnloadSignals(GLOBALS->extload_ffr_ctx);
+		fsdbReaderResetSignalList(GLOBALS->extload_ffr_ctx);
 		}
 	GLOBALS->extload_ffr_import_count++;
 
