@@ -1,4 +1,4 @@
-/* 
+/*
  * Copyright (c) Tony Bybell 1999.
  *
  * This program is free software; you can redistribute it and/or
@@ -17,6 +17,9 @@
 void
 fetch_left(GtkWidget *text, gpointer data)
 {
+(void)text;
+(void)data;
+
 TimeType newlo;
 char fromstr[32];
 
@@ -41,12 +44,12 @@ if(newlo<=GLOBALS->min_time) newlo=GLOBALS->min_time;
 reformat_time(fromstr, newlo, GLOBALS->time_dimension);
 
 gtk_entry_set_text(GTK_ENTRY(GLOBALS->from_entry),fromstr);
-         
+
 if(newlo<(GLOBALS->tims.last))
         {
         GLOBALS->tims.first=newlo;
         if(GLOBALS->tims.start<GLOBALS->tims.first) GLOBALS->tims.start=GLOBALS->tims.first;
-        
+
         time_update();
         }
 }
@@ -55,6 +58,9 @@ if(newlo<(GLOBALS->tims.last))
 void
 fetch_right(GtkWidget *text, gpointer data)
 {
+(void)text;
+(void)data;
+
 TimeType newhi;
 char tostr[32];
 
@@ -79,7 +85,7 @@ if(newhi>=GLOBALS->max_time) newhi=GLOBALS->max_time;
 reformat_time(tostr, newhi, GLOBALS->time_dimension);
 
 gtk_entry_set_text(GTK_ENTRY(GLOBALS->to_entry),tostr);
-         
+
 if(newhi>(GLOBALS->tims.first))
         {
         GLOBALS->tims.last=newhi;
@@ -91,6 +97,9 @@ if(newhi>(GLOBALS->tims.first))
 void
 discard_left(GtkWidget *text, gpointer data)
 {
+(void)text;
+(void)data;
+
 TimeType newlo;
 char tostr[32];
 
@@ -99,7 +108,7 @@ if(GLOBALS->helpbox_is_active)
         help_text_bold("\n\nDiscard Left");
         help_text(
                 " increases the \"From\" time, which allows less of the trace"
-                " to be displayed."                                             
+                " to be displayed."
         );
         return;
         }
@@ -113,7 +122,7 @@ if(newlo<(GLOBALS->tims.last))
 	{
 	reformat_time(tostr, newlo, GLOBALS->time_dimension);
 	gtk_entry_set_text(GTK_ENTRY(GLOBALS->from_entry),tostr);
-         
+
 	GLOBALS->tims.first=newlo;
 	time_update();
 	}
@@ -122,6 +131,9 @@ if(newlo<(GLOBALS->tims.last))
 void
 discard_right(GtkWidget *text, gpointer data)
 {
+(void)text;
+(void)data;
+
 TimeType newhi;
 char tostr[32];
 
@@ -144,7 +156,7 @@ if(newhi>(GLOBALS->tims.first))
 	{
 	reformat_time(tostr, newhi, GLOBALS->time_dimension);
 	gtk_entry_set_text(GTK_ENTRY(GLOBALS->to_entry),tostr);
-         
+
 	GLOBALS->tims.last=newhi;
 	time_update();
 	}
@@ -171,7 +183,7 @@ pixmapwid1=gtk_pixmap_new(GLOBALS->larrow_pixmap, GLOBALS->larrow_mask);
 gtk_widget_show(pixmapwid1);
 pixmapwid2=gtk_pixmap_new(GLOBALS->rarrow_pixmap, GLOBALS->rarrow_mask);
 gtk_widget_show(pixmapwid2);
-   
+
 /* Create a table to hold the text widget and scrollbars */
 table = gtk_table_new (1, 1, FALSE);
 
@@ -209,4 +221,4 @@ gtk_container_add (GTK_CONTAINER (frame), table2);
 gtk_widget_show(table2);
 return(table);
 }
-   
+
