@@ -26,6 +26,10 @@ open_callback(GConfClient* gclient,
                      GConfEntry *entry,
                      gpointer user_data)
 {
+(void)gclient;
+(void)cnxn_id;
+(void)user_data;
+
   if (gconf_entry_get_value (entry) == NULL)
     {
       /* value is unset */
@@ -53,6 +57,10 @@ quit_callback(GConfClient* gclient,
                      GConfEntry *entry,
                      gpointer user_data)
 {
+(void)gclient;
+(void)cnxn_id;
+(void)user_data;
+
   if (gconf_entry_get_value (entry) == NULL)
     {
       /* value is unset */
@@ -81,6 +89,10 @@ reload_callback(GConfClient* gclient,
                      GConfEntry *entry,
                      gpointer user_data)
 {
+(void)gclient;
+(void)cnxn_id;
+(void)user_data;
+
   if (gconf_entry_get_value (entry) == NULL)
     {
       /* value is unset */
@@ -101,12 +113,46 @@ reload_callback(GConfClient* gclient,
 }
 
 
+static void
+zoomfull_callback(GConfClient* gclient,
+                     guint cnxn_id,
+                     GConfEntry *entry,
+                     gpointer user_data)
+{
+(void)gclient;
+(void)cnxn_id;
+(void)user_data;
+
+  if (gconf_entry_get_value (entry) == NULL)
+    {
+      /* value is unset */
+    }
+  else
+    {
+      if (gconf_entry_get_value (entry)->type == GCONF_VALUE_STRING)
+        {
+	  if(in_main_iteration()) return;
+	  service_zoom_full(NULL, NULL);
+	  gconf_entry_set_value(entry, NULL);
+        }
+      else
+        {
+          /* value is of wrong type */
+        }
+    }
+}
+
+
 static void
 writesave_callback(GConfClient* gclient,
                      guint cnxn_id,
                      GConfEntry *entry,
                      gpointer user_data)
 {
+(void)gclient;
+(void)cnxn_id;
+(void)user_data;
+
   if (gconf_entry_get_value (entry) == NULL)
     {
       /* value is unset */
@@ -123,7 +169,7 @@ writesave_callback(GConfClient* gclient,
 		  if(fn)
 			{
 		  	FILE *wave;
-	
+
 		  	if(!(wave=fopen(fn, "wb")))
 		        	{
 		        	fprintf(stderr, "GTKWAVE | RPC Writesave: error opening save file '%s' for writing.\n", fn);
@@ -154,6 +200,84 @@ writesave_callback(GConfClient* gclient,
     }
 }
 
+
+static void
+move_to_time_callback(GConfClient* gclient,
+                     guint cnxn_id,
+                     GConfEntry *entry,
+                     gpointer user_data)
+{
+(void)gclient;
+(void)cnxn_id;
+(void)user_data;
+
+  if (gconf_entry_get_value (entry) == NULL)
+    {
+      /* value is unset */
+    }
+  else
+    {
+      if (gconf_entry_get_value (entry)->type == GCONF_VALUE_STRING)
+        {
+	  const char *str = gconf_value_get_string (gconf_entry_get_value (entry));
+	  if(str && !in_main_iteration())
+		{
+		char *e_copy = GLOBALS->entrybox_text;
+	        GLOBALS->entrybox_text=strdup_2(str);
+
+		movetotime_cleanup(NULL, NULL);
+
+		GLOBALS->entrybox_text = e_copy;
+		}
+
+	  gconf_entry_set_value(entry, NULL);
+        }
+      else
+        {
+          /* value is of wrong type */
+        }
+    }
+}
+
+
+static void
+zoom_size_callback(GConfClient* gclient,
+                     guint cnxn_id,
+                     GConfEntry *entry,
+                     gpointer user_data)
+{
+(void)gclient;
+(void)cnxn_id;
+(void)user_data;
+
+  if (gconf_entry_get_value (entry) == NULL)
+    {
+      /* value is unset */
+    }
+  else
+    {
+      if (gconf_entry_get_value (entry)->type == GCONF_VALUE_STRING)
+        {
+	  const char *str = gconf_value_get_string (gconf_entry_get_value (entry));
+	  if(str && !in_main_iteration())
+		{
+		char *e_copy = GLOBALS->entrybox_text;
+	        GLOBALS->entrybox_text=strdup_2(str);
+
+		zoomsize_cleanup(NULL, NULL);
+
+		GLOBALS->entrybox_text = e_copy;
+		}
+
+	  gconf_entry_set_value(entry, NULL);
+        }
+      else
+        {
+          /* value is of wrong type */
+        }
+    }
+}
+
 /************************************************************/
 
 static void remove_client(void)
@@ -192,18 +316,36 @@ if(!client)
 	                          quit_callback,
 	                          NULL, /* user data */
 	                          NULL, NULL);
-	
+
 	strcpy(ks + len, "/writesave");
 	gconf_client_notify_add(client, ks,
 	                          writesave_callback,
 	                          NULL, /* user data */
 	                          NULL, NULL);
-	
+
 	strcpy(ks + len, "/reload");
 	gconf_client_notify_add(client, ks,
 	                          reload_callback,
 	                          NULL, /* user data */
 	                          NULL, NULL);
+
+	strcpy(ks + len, "/zoom_full");
+	gconf_client_notify_add(client, ks,
+	                          zoomfull_callback,
+	                          NULL, /* user data */
+	                          NULL, NULL);
+
+	strcpy(ks + len, "/move_to_time");
+	gconf_client_notify_add(client, ks,
+	                          move_to_time_callback,
+	                          NULL, /* user data */
+	                          NULL, NULL);
+
+	strcpy(ks + len, "/zoom_size");
+	gconf_client_notify_add(client, ks,
+	                          zoom_size_callback,
+	                          NULL, /* user data */
+	                          NULL, NULL);
 	}
 }
 
@@ -267,15 +409,26 @@ if(dumpfile && savefile && rcfile && wave_pwd && opt_vcd)
 
 void wave_gconf_init(int argc, char **argv)
 {
+(void)argc;
+(void)argv;
 }
 
 gboolean wave_gconf_client_set_string(const gchar *key, const gchar *val)
 {
+(void)key;
+(void)val;
+
 return(FALSE);
 }
 
 void wave_gconf_restore(char **dumpfile, char **savefile, char **rcfile, char **wave_pwd, int *opt_vcd)
 {
+(void)dumpfile;
+(void)savefile;
+(void)rcfile;
+(void)wave_pwd;
+(void)opt_vcd;
+
 /* nothing */
 }
 
@@ -295,7 +448,11 @@ gconftool-2 --type string --set /com.geda.gtkwave/0/writesave /tmp/this.gtkw
 gconftool-2 --type string --set /com.geda.gtkwave/0/writesave +
 
 gconftool-2 --type string --set /com.geda.gtkwave/0/quit 0
-
 gconftool-2 --type string --set /com.geda.gtkwave/0/reload 0
 
+gconftool-2 --type string --set /com.geda.gtkwave/0/zoom_full 0
+gconftool-2 --type string --set /com.geda.gtkwave/0/zoom_size -- -4.6
+gconftool-2 --type string --set /com.geda.gtkwave/0/move_to_time 123ns
+gconftool-2 --type string --set /com.geda.gtkwave/0/move_to_time A
+
 */
