@@ -243,6 +243,8 @@ NULL, /* extload_inv_idcodes */
 0, /* extload_already_errored */
 #endif
 NULL, /* extload_namecache */
+NULL, /* extload_namecache_max */
+NULL, /* extload_namecache_lens */
 NULL, /* extload_sym_block */
 NULL, /* extload_node_block */
 NULL, /* extload_xc */
@@ -252,6 +254,8 @@ NULL, /* extload_prevsym */
 0, /* extload_hlen */
 0, /* extload_vt_prev */
 0, /* extload_vd_prev */
+0, /* f_name_build_buf_len */
+NULL, /* f_name_build_buf */
 
 
 /*
