@@ -242,6 +242,8 @@ time_t extload_lastmod; /* from extload.c */
 char extload_already_errored; /* from extload.c */
 #endif
 char **extload_namecache;
+int *extload_namecache_max;
+int *extload_namecache_lens;
 struct symbol *extload_sym_block;
 struct Node *extload_node_block;
 void *extload_xc;
@@ -251,6 +253,8 @@ int extload_i;
 int extload_hlen;
 unsigned char extload_vt_prev;
 unsigned char extload_vd_prev;
+int f_name_build_buf_len;
+char *f_name_build_buf;
 
 
 /*
