@@ -31,7 +31,7 @@
 #include "wave_locale.h"
 
 static char *match = NULL;
-static int matchlen = 0;
+static uint32_t matchlen = 0;
 static int names_only = 0;
 static char *killed_list = NULL;
 char killed_value = 1;
@@ -124,7 +124,7 @@ lt=vzt_rd_init(fname);
 if(lt)
 	{
 	int numfacs;
-	
+
 	vzt_rd_vectorize(lt);			/* coalesce bitblasted vectors */
 	numfacs = vzt_rd_get_num_facs(lt);
 	killed_list = calloc(numfacs, sizeof(char));
@@ -149,7 +149,7 @@ return(0);
 
 void print_help(char *nam)
 {
-#ifdef __linux__ 
+#ifdef __linux__
 printf(
 "Usage: %s [OPTION]... [VZTFILE]\n\n"
 "  -d, --dumpfile=FILE        specify VZT input dumpfile\n"
@@ -183,7 +183,7 @@ char opt_errors_encountered=0;
 char *lxname=NULL;
 int c;
 int rc;
-int i, j, k;
+uint32_t i, j, k;
 int comprehensive = 0;
 
 
@@ -193,7 +193,7 @@ while (1)
         {
 #ifdef __linux__
         int option_index = 0;
-                        
+
         static struct option long_options[] =
                 {
 		{"dumpfile", 1, 0, 'd'},
@@ -202,16 +202,16 @@ while (1)
 		{"namesonly", 0, 0, 'n'},
 		{"comprehensive", 0, 0, 'c'},
                 {"help", 0, 0, 'h'},
-                {0, 0, 0, 0}  
+                {0, 0, 0, 0}
                 };
-                
+
         c = getopt_long (argc, argv, "d:m:x:nch", long_options, &option_index);
 #else
         c = getopt      (argc, argv, "d:m:x:nch");
 #endif
-                        
+
         if (c == -1) break;     /* no more args */
-                        
+
         switch (c)
                 {
 		case 'c':
@@ -278,29 +278,29 @@ while (1)
                 case 'h':
 			print_help(argv[0]);
                         break;
-                        
+
                 case '?':
                         opt_errors_encountered=1;
                         break;
-                        
+
                 default:
                         /* unreachable */
                         break;
                 }
         }
 
-if(!names_only && comprehensive) 
+if(!names_only && comprehensive)
 	{
 	killed_value = 0;
 	}
-                        
+
 if(opt_errors_encountered)
         {
         print_help(argv[0]);
         }
 
 if (optind < argc)
-        {               
+        {
         while (optind < argc)
                 {
                 if(lxname)
@@ -311,7 +311,7 @@ if (optind < argc)
                 strcpy(lxname, argv[optind++]);
                 }
         }
-                        
+
 if(!lxname)
         {
         print_help(argv[0]);
