@@ -1,5 +1,5 @@
 /*
- * Copyright (c) Tony Bybell 2008-2012.
+ * Copyright (c) Tony Bybell 2008-2014.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -54,6 +54,8 @@
 
 static int gtkwavetcl_badNumArgs(ClientData clientData, Tcl_Interp *interp, int objc, Tcl_Obj *CONST objv[], int expected)
 {
+(void)clientData;
+
 Tcl_Obj *aobj;
 char reportString[1024];
 
@@ -66,6 +68,11 @@ return(TCL_ERROR);
 
 static int gtkwavetcl_nop(ClientData clientData, Tcl_Interp *interp, int objc, Tcl_Obj *CONST objv[])
 {
+(void)clientData;
+(void)interp;
+(void)objc;
+(void)objv;
+
 /* nothing, this is simply to call gtk's main loop */
 gtkwave_main_iteration();
 return(TCL_OK);
@@ -73,12 +80,16 @@ return(TCL_OK);
 
 static int gtkwavetcl_printInteger(ClientData clientData, Tcl_Interp *interp, int objc, Tcl_Obj *CONST objv[], int intVal)
 {
+(void)clientData;
+(void)objc;
+(void)objv;
+
 Tcl_Obj *aobj;
 char reportString[33];
 
 sprintf(reportString, "%d", intVal);
 
-aobj = Tcl_NewStringObj(reportString, -1); 
+aobj = Tcl_NewStringObj(reportString, -1);
 Tcl_SetObjResult(interp, aobj);
 
 return(TCL_OK);
@@ -86,12 +97,16 @@ return(TCL_OK);
 
 static int gtkwavetcl_printTimeType(ClientData clientData, Tcl_Interp *interp, int objc, Tcl_Obj *CONST objv[], TimeType ttVal)
 {
+(void)clientData;
+(void)objc;
+(void)objv;
+
 Tcl_Obj *aobj;
 char reportString[65];
 
 sprintf(reportString, TTFormat, ttVal);
 
-aobj = Tcl_NewStringObj(reportString, -1); 
+aobj = Tcl_NewStringObj(reportString, -1);
 Tcl_SetObjResult(interp, aobj);
 
 return(TCL_OK);
@@ -99,12 +114,16 @@ return(TCL_OK);
 
 static int gtkwavetcl_printDouble(ClientData clientData, Tcl_Interp *interp, int objc, Tcl_Obj *CONST objv[], double dVal)
 {
+(void)clientData;
+(void)objc;
+(void)objv;
+
 Tcl_Obj *aobj;
 char reportString[65];
 
 sprintf(reportString, "%e", dVal);
 
-aobj = Tcl_NewStringObj(reportString, -1); 
+aobj = Tcl_NewStringObj(reportString, -1);
 Tcl_SetObjResult(interp, aobj);
 
 return(TCL_OK);
@@ -112,9 +131,13 @@ return(TCL_OK);
 
 static int gtkwavetcl_printString(ClientData clientData, Tcl_Interp *interp, int objc, Tcl_Obj *CONST objv[], const char *reportString)
 {
+(void)clientData;
+(void)objc;
+(void)objv;
+
 Tcl_Obj *aobj;
 
-aobj = Tcl_NewStringObj(reportString, -1); 
+aobj = Tcl_NewStringObj(reportString, -1);
 Tcl_SetObjResult(interp, aobj);
 
 return(TCL_OK);
@@ -197,12 +220,12 @@ if(objc == 2)
 
         	hfacname = hier_decompress_flagged(GLOBALS->facs[which]->name, &was_packed);
 
-		aobj = Tcl_NewStringObj(hfacname, -1); 
+		aobj = Tcl_NewStringObj(hfacname, -1);
 		Tcl_SetObjResult(interp, aobj);
 		if(was_packed) free_2(hfacname);
 		}
 	}
-        else  
+        else
         {
         return(gtkwavetcl_badNumArgs(clientData, interp, objc, objv, 1));
         }
@@ -230,6 +253,10 @@ return(gtkwavetcl_printTimeType(clientData, interp, objc, objv, value));
 
 static int gtkwavetcl_getTimeDimension(ClientData clientData, Tcl_Interp *interp, int objc, Tcl_Obj *CONST objv[])
 {
+(void)clientData;
+(void)objc;
+(void)objv;
+
 Tcl_Obj *aobj;
 char reportString[2];
 
@@ -244,6 +271,10 @@ return(TCL_OK);
 
 static int gtkwavetcl_getArgv(ClientData clientData, Tcl_Interp *interp, int objc, Tcl_Obj *CONST objv[])
 {
+(void)clientData;
+(void)objc;
+(void)objv;
+
 if(GLOBALS->argvlist)
 	{
 	Tcl_Obj *aobj = Tcl_NewStringObj(GLOBALS->argvlist, -1);
@@ -279,15 +310,19 @@ return(gtkwavetcl_printTimeType(clientData, interp, objc, objv, value));
 
 static int gtkwavetcl_getDumpType(ClientData clientData, Tcl_Interp *interp, int objc, Tcl_Obj *CONST objv[])
 {
+(void)clientData;
+(void)objc;
+(void)objv;
+
 Tcl_Obj *aobj;
 char *reportString = "UNKNOWN";
 
-if(GLOBALS->is_vcd) 
+if(GLOBALS->is_vcd)
         {
         if(GLOBALS->partial_vcd)
                 {
                 reportString = "PVCD";
-                }  
+                }
                 else
                 {
                 reportString = "VCD";
@@ -329,28 +364,29 @@ static int gtkwavetcl_getNamedMarker(ClientData clientData, Tcl_Interp *interp,
 if(objc == 2)
 	{
 	char *s = get_Tcl_string(objv[1]);
-	int which;
+	int which = -1;
 
 	if((s[0]>='A')&&(s[0]<='Z'))
 		{
-		TimeType value = GLOBALS->named_markers[s[0] - 'A'];
-		return(gtkwavetcl_printTimeType(clientData, interp, objc, objv, value));
+		which = bijective_marker_id_string_hash(s);
 		}
 	else
 	if((s[0]>='a')&&(s[0]<='z'))
 		{
-		TimeType value = GLOBALS->named_markers[s[0] - 'a'];
-		return(gtkwavetcl_printTimeType(clientData, interp, objc, objv, value));
+		which = bijective_marker_id_string_hash(s);
+		}
+	else
+		{
+		which = atoi(s); 
 		}
 
-	which = atoi(s);
-	if((which >= 0) && (which < 26))
+	if((which >= 0) && (which < WAVE_NUM_NAMED_MARKERS))
 		{
 		TimeType value = GLOBALS->named_markers[which];
 		return(gtkwavetcl_printTimeType(clientData, interp, objc, objv, value));
 		}
 	}
-        else  
+        else
         {
         return(gtkwavetcl_badNumArgs(clientData, interp, objc, objv, 1));
         }
@@ -436,7 +472,7 @@ if(objc == 2)
 			}
 		}
 	}
-        else  
+        else
         {
         return(gtkwavetcl_badNumArgs(clientData, interp, objc, objv, 2));
         }
@@ -467,7 +503,7 @@ if(objc == 2)
 			}
 		}
 	}
-        else  
+        else
         {
         return(gtkwavetcl_badNumArgs(clientData, interp, objc, objv, 1));
         }
@@ -508,7 +544,7 @@ if(objc == 2)
 			}
 		}
 	}
-        else  
+        else
         {
         return(gtkwavetcl_badNumArgs(clientData, interp, objc, objv, 1));
         }
@@ -548,7 +584,7 @@ if(objc == 2)
 			}
 		}
 	}
-        else  
+        else
         {
         return(gtkwavetcl_badNumArgs(clientData, interp, objc, objv, 1));
         }
@@ -568,19 +604,19 @@ if(objc == 3)
 
 	if((sv[0]>='A')&&(sv[0]<='Z'))
 		{
-		which = sv[0] - 'A';
+		which = bijective_marker_id_string_hash(sv);
 		}
 	else
 	if((sv[0]>='a')&&(sv[0]<='z'))
 		{
-		which = sv[0] - 'a';
+		which = bijective_marker_id_string_hash(sv);
 		}
 	else
 		{
 		which = atoi(sv);
 		}
 
-	if((which >= 0) && (which < 26))
+	if((which >= 0) && (which < WAVE_NUM_NAMED_MARKERS))
 		{
 		char *s = get_Tcl_string(objv[2]);
 		Trptr t = GLOBALS->traces.first;
@@ -617,7 +653,7 @@ if(objc == 3)
 				char *pnt = t->asciivalue;
 				if(*pnt == '=') pnt++;
 
-				aobj = Tcl_NewStringObj(pnt, -1); 
+				aobj = Tcl_NewStringObj(pnt, -1);
 				Tcl_SetObjResult(interp, aobj);
 
 				GLOBALS->tims.marker = oldmarker;
@@ -641,7 +677,7 @@ if(objc == 3)
 			}
 		}
 	}
-        else  
+        else
         {
         return(gtkwavetcl_badNumArgs(clientData, interp, objc, objv, 1));
         }
@@ -723,7 +759,7 @@ if(objc == 2)
 
 	gtkwave_main_iteration();
 	}
-        else  
+        else
         {
         return(gtkwavetcl_badNumArgs(clientData, interp, objc, objv, 1));
         }
@@ -756,7 +792,7 @@ if(objc == 2)
 
 	gtkwave_main_iteration();
 	}
-        else  
+        else
         {
         return(gtkwavetcl_badNumArgs(clientData, interp, objc, objv, 1));
         }
@@ -778,11 +814,11 @@ if(objc == 2)
 	        GtkAdjustment *hadj;
 	        TimeType pageinc;
 
-	        gt=unformat_time(s, GLOBALS->time_dimension);    
-          
+	        gt=unformat_time(s, GLOBALS->time_dimension);
+
 	        if(gt<GLOBALS->tims.first) gt=GLOBALS->tims.first;
 	        else if(gt>GLOBALS->tims.last) gt=GLOBALS->tims.last;
- 
+
 	        hadj=GTK_ADJUSTMENT(GLOBALS->wave_hslider);
 	        hadj->value=gt;
 
@@ -794,9 +830,9 @@ if(objc == 2)
 	                GLOBALS->tims.timecache=GLOBALS->tims.last-pageinc+1;
 	                if(GLOBALS->tims.timecache<GLOBALS->tims.first) GLOBALS->tims.timecache=GLOBALS->tims.first;
 	                }
-	
+
 	        reformat_time(timval,GLOBALS->tims.timecache,GLOBALS->time_dimension);
-	        
+
 	        time_update();
 	        }
 
@@ -804,7 +840,7 @@ if(objc == 2)
         wavearea_configure_event(GLOBALS->wavearea, NULL);
 	gtkwave_main_iteration();
 	}
-        else  
+        else
         {
         return(gtkwavetcl_badNumArgs(clientData, interp, objc, objv, 1));
         }
@@ -818,7 +854,7 @@ if(objc == 2)
         {
         char *s = get_Tcl_string(objv[1]);
         float f;
-         
+
         sscanf(s, "%f", &f);
         if(f>0.0)
                 {
@@ -828,9 +864,9 @@ if(objc == 2)
         if(f<-62.0)
                 {
                 f=-62.0; /* in case they try to go out of range */
-                } 
-                
-        GLOBALS->tims.prevzoom=GLOBALS->tims.zoom; 
+                }
+
+        GLOBALS->tims.prevzoom=GLOBALS->tims.zoom;
         GLOBALS->tims.zoom=(gdouble)f;
         calczoom(GLOBALS->tims.zoom);
         fix_wavehadj();
@@ -840,7 +876,7 @@ if(objc == 2)
 
 	gtkwave_main_iteration();
 	}
-        else  
+        else
         {
         return(gtkwavetcl_badNumArgs(clientData, interp, objc, objv, 1));
         }
@@ -876,7 +912,7 @@ if(objc == 3)
 
 	gtkwave_main_iteration();
 	}
-        else  
+        else
         {
         return(gtkwavetcl_badNumArgs(clientData, interp, objc, objv, 1));
         }
@@ -897,7 +933,7 @@ if(objc == 2)
 
 	gtkwave_main_iteration();
 	}
-        else  
+        else
         {
         return(gtkwavetcl_badNumArgs(clientData, interp, objc, objv, 1));
         }
@@ -912,28 +948,28 @@ if((objc == 3)||(objc == 4))
         char *s = get_Tcl_string(objv[1]);
 	int which = -1;
 
-        if((s[0]>='A')&&(s[0]<='Z'))  
+        if((s[0]>='A')&&(s[0]<='Z'))
                 {
-                which = s[0] - 'A';
+		which = bijective_marker_id_string_hash(s);
                 }
         else
-        if((s[0]>='a')&&(s[0]<='z'))  
+        if((s[0]>='a')&&(s[0]<='z'))
                 {
-                which = s[0] - 'a';
+		which = bijective_marker_id_string_hash(s);
                 }
-	else                
+	else
 		{
 	        which = atoi(s);
 		}
 
-        if((which >= 0) && (which < 26))
+        if((which >= 0) && (which < WAVE_NUM_NAMED_MARKERS))
                 {
 	        char *t = get_Tcl_string(objv[2]);
 		TimeType gt=unformat_time(t, GLOBALS->time_dimension);
 
                 GLOBALS->named_markers[which] = gt;
 
-		if(GLOBALS->marker_names[which]) 
+		if(GLOBALS->marker_names[which])
 			{
 			free_2(GLOBALS->marker_names[which]);
 			GLOBALS->marker_names[which] = NULL;
@@ -948,9 +984,9 @@ if((objc == 3)||(objc == 4))
 
 	        wavearea_configure_event(GLOBALS->wavearea, NULL);
 		gtkwave_main_iteration();
-                } 
+                }
 	}
-        else  
+        else
         {
         return(gtkwavetcl_badNumArgs(clientData, interp, objc, objv, 2));
         }
@@ -983,7 +1019,7 @@ if(objc == 2)
 /*         gtk_signal_emit_by_name (GTK_OBJECT (wadj), "value_changed"); /\* force text update *\/ */
 /*	gtkwave_main_iteration(); */
 	}
-        else  
+        else
         {
         return(gtkwavetcl_badNumArgs(clientData, interp, objc, objv, 1));
         }
@@ -1032,7 +1068,7 @@ if(objc==2)
         		}
                 }
 	}
-        else  
+        else
         {
         return(gtkwavetcl_badNumArgs(clientData, interp, objc, objv, 1));
         }
@@ -1059,14 +1095,14 @@ if(objc==2)
 	int l = 0;
 
 	elem = zSplitTclList(s, &l);
- 
+
 	if(elem)
         	{
 		Trptr t = GLOBALS->traces.first;
 		while(t)
 			{
 			t->cached_flags = t->flags;
-			t->flags &= (~TR_HIGHLIGHT);	
+			t->flags &= (~TR_HIGHLIGHT);
 			t = t->t_next;
 			}
 
@@ -1123,7 +1159,7 @@ if(objc==2)
         		}
                 }
 	}
-        else  
+        else
         {
         return(gtkwavetcl_badNumArgs(clientData, interp, objc, objv, 1));
         }
@@ -1150,15 +1186,15 @@ if(objc==2)
 	int l = 0;
 
 	elem = zSplitTclList(s, &l);
- 
+
 	if(elem)
         	{
 		Trptr t = GLOBALS->traces.first;
 		while(t)
 			{
 			t->cached_flags = t->flags;
-			t->flags &= (~TR_HIGHLIGHT);	
-		
+			t->flags &= (~TR_HIGHLIGHT);
+
 			if(!(t->flags&(TR_BLANK|TR_ANALOG_BLANK_STRETCH)))
 				{
 				char *name = extractFullTraceName(t);
@@ -1210,7 +1246,7 @@ if(objc==2)
         		}
                 }
 	}
-        else  
+        else
         {
         return(gtkwavetcl_badNumArgs(clientData, interp, objc, objv, 1));
         }
@@ -1237,7 +1273,7 @@ if(objc==2)
 	int l = 0;
 
 	elem = zSplitTclList(s, &l);
- 
+
 	if(elem)
         	{
 		Trptr t = GLOBALS->traces.first;
@@ -1276,7 +1312,7 @@ if(objc==2)
         		}
                 }
 	}
-        else  
+        else
         {
         return(gtkwavetcl_badNumArgs(clientData, interp, objc, objv, 1));
         }
@@ -1303,7 +1339,7 @@ if(objc==2)
 	int l = 0;
 
 	elem = zSplitTclList(s, &l);
- 
+
 	if(elem)
         	{
 		Trptr t = GLOBALS->traces.first;
@@ -1342,7 +1378,7 @@ if(objc==2)
         		}
                 }
 	}
-        else  
+        else
         {
         return(gtkwavetcl_badNumArgs(clientData, interp, objc, objv, 1));
         }
@@ -1391,7 +1427,7 @@ if(objc == 3)
 			}
 		}
 	}
-        else  
+        else
         {
         return(gtkwavetcl_badNumArgs(clientData, interp, objc, objv, 2));
         }
@@ -1452,6 +1488,8 @@ return(TCL_OK);
 
 static int gtkwavetcl_signalChangeList(ClientData clientData, Tcl_Interp *interp,
 				       int objc, Tcl_Obj *CONST objv[]) {
+(void) clientData;
+
     int dir = STRACE_FORWARD ;
     TimeType start_time = 0 ;
     TimeType end_time = MAX_HISTENT_TIME ;
@@ -1506,7 +1544,7 @@ static int gtkwavetcl_signalChangeList(ClientData clientData, Tcl_Interp *interp
 	  else {
 	    if(strstr("forward", str1_p))
 	      dir = STRACE_FORWARD ;
-	    else 
+	    else
 	      if(strstr("backward", str1_p))
 		dir = STRACE_BACKWARD ;
 	      else
@@ -1531,10 +1569,10 @@ static int gtkwavetcl_signalChangeList(ClientData clientData, Tcl_Interp *interp
     }
     if(error) {
       Tcl_SetObjResult
-	(interp, 
+	(interp,
 	 Tcl_NewStringObj("Usage: signal_change_list ?name? ?-start time? ?-end time? ?-max size? ?-dir forward|backward?", -1)) ;
       return TCL_ERROR;
-    } 
+    }
     l_head = signal_change_list(sig_name, dir, start_time, end_time, max_elements) ;
     l_obj = Tcl_NewListObj(0, NULL) ;
     p = l_head;
@@ -1576,7 +1614,7 @@ static int gtkwavetcl_forceOpenTreeNode(ClientData clientData, Tcl_Interp *inter
   char *s = NULL ;
   if(objc == 2)
     s = get_Tcl_string(objv[1]);
-  
+
   if(s && (strlen(s) > 1)) {	/* exclude empty strings */
     int len = strlen(s);
     if(s[len-1]!=GLOBALS->hier_delimeter)
@@ -1603,7 +1641,7 @@ static int gtkwavetcl_forceOpenTreeNode(ClientData clientData, Tcl_Interp *inter
 		   Tcl_NewStringObj(GLOBALS->selected_hierarchy_name,
 				    strlen(GLOBALS->selected_hierarchy_name)) :
 		   Tcl_NewIntObj(rv)) ;
-  
+
   return(TCL_OK);
 }
 
@@ -1616,12 +1654,12 @@ if(objc == 2)
 	if(s)
 		{
 		gtk_entry_set_text(GTK_ENTRY(GLOBALS->from_entry),s);
-		from_entry_callback(NULL, GLOBALS->from_entry);		
+		from_entry_callback(NULL, GLOBALS->from_entry);
 		}
 
 	gtkwave_main_iteration();
 	}
-        else  
+        else
         {
         return(gtkwavetcl_badNumArgs(clientData, interp, objc, objv, 1));
         }
@@ -1639,12 +1677,12 @@ if(objc == 2)
 	if(s)
 		{
 		gtk_entry_set_text(GTK_ENTRY(GLOBALS->to_entry),s);
-		to_entry_callback(NULL, GLOBALS->to_entry);		
+		to_entry_callback(NULL, GLOBALS->to_entry);
 		}
 
 	gtkwave_main_iteration();
 	}
-        else  
+        else
         {
         return(gtkwavetcl_badNumArgs(clientData, interp, objc, objv, 1));
         }
@@ -1662,7 +1700,7 @@ if(value)
         }
 
 return(TCL_OK);
-}       
+}
 
 
 static int gtkwavetcl_getToEntry(ClientData clientData, Tcl_Interp *interp, int objc, Tcl_Obj *CONST objv[])
@@ -1674,7 +1712,7 @@ if(value)
         }
 
 return(TCL_OK);
-}       
+}
 
 
 static int gtkwavetcl_getDisplayedSignals(ClientData clientData, Tcl_Interp *interp, int objc, Tcl_Obj *CONST objv[])
@@ -1721,7 +1759,7 @@ if(objc == 2)
 		return(gtkwavetcl_printInteger(clientData, interp, objc, objv, t->flags));
 		}
 	}
-        else  
+        else
         {
         return(gtkwavetcl_badNumArgs(clientData, interp, objc, objv, 1));
         }
@@ -1734,8 +1772,8 @@ static int gtkwavetcl_loadFile(ClientData clientData, Tcl_Interp *interp, int ob
   if(objc == 2)
     {
       char *s = get_Tcl_string(objv[1]);
-	
-      if(!GLOBALS->in_tcl_callback)                          
+
+      if(!GLOBALS->in_tcl_callback)
         {
 	/* wave_gconf_client_set_string("/current/savefile", s); */
         /*	read_save_helper(s, NULL, NULL, NULL, NULL); */
@@ -1748,7 +1786,7 @@ static int gtkwavetcl_loadFile(ClientData clientData, Tcl_Interp *interp, int ob
 	gtkwavetcl_setvar_nonblocking(WAVE_TCLCB_ERROR,"gtkwave::loadFile prohibited in callback",WAVE_TCLCB_ERROR_FLAGS);
 	}
     }
-  else  
+  else
     {
       return(gtkwavetcl_badNumArgs(clientData, interp, objc, objv, 1));
     }
@@ -1770,7 +1808,7 @@ static int gtkwavetcl_reLoadFile(ClientData clientData, Tcl_Interp *interp, int
 	gtkwavetcl_setvar_nonblocking(WAVE_TCLCB_ERROR,"gtkwave::reLoadFile prohibited in callback",WAVE_TCLCB_ERROR_FLAGS);
 	}
     }
-  else  
+  else
     {
       return(gtkwavetcl_badNumArgs(clientData, interp, objc, objv, 0));
     }
@@ -1782,13 +1820,13 @@ static int gtkwavetcl_presentWindow(ClientData clientData, Tcl_Interp *interp, i
 
   if(objc == 1)
     {
-#ifdef WAVE_USE_GTK2 
+#ifdef WAVE_USE_GTK2
       gtk_window_present(GTK_WINDOW(GLOBALS->mainwindow));
 #else
       gdk_window_raise(GTK_WIDGET(GLOBALS->mainwindow)->window);
 #endif
     }
-  else  
+  else
     {
       return(gtkwavetcl_badNumArgs(clientData, interp, objc, objv, 0));
     }
@@ -1812,7 +1850,7 @@ static int gtkwavetcl_showSignal(ClientData clientData, Tcl_Interp *interp, int
 
       SetTraceScrollbarRowValue(row, location);
     }
-  else  
+  else
     {
       return(gtkwavetcl_badNumArgs(clientData, interp, objc, objv, 2));
     }
@@ -1821,18 +1859,18 @@ static int gtkwavetcl_showSignal(ClientData clientData, Tcl_Interp *interp, int
 }
 
 
-/* 
+/*
  * swap to a given context based on tab number (from Tcl)
  */
 static gint switch_to_tab_number(unsigned int i)
-{       
-if(i < GLOBALS->num_notebook_pages)  
+{
+if(i < GLOBALS->num_notebook_pages)
         {
         struct Global *g_old = GLOBALS;
         /* printf("Switching to: %d\n", i); */
 
         set_GLOBALS((*GLOBALS->contexts)[i]);
-        
+
         GLOBALS->lxt_clock_compress_to_z = g_old->lxt_clock_compress_to_z;
         GLOBALS->autoname_bundles = g_old->autoname_bundles;
         GLOBALS->autocoalesce_reversal = g_old->autocoalesce_reversal;
@@ -1851,23 +1889,23 @@ if(i < GLOBALS->num_notebook_pages)
         GLOBALS->highlight_wavewindow = g_old->highlight_wavewindow;
         GLOBALS->disable_mouseover = g_old->disable_mouseover;
         GLOBALS->zoom_pow10_snap = g_old->zoom_pow10_snap;
-                                         
+
         GLOBALS->scale_to_time_dimension = g_old->scale_to_time_dimension;
         GLOBALS->zoom_dyn = g_old->zoom_dyn;
         GLOBALS->zoom_dyne = g_old->zoom_dyne;
-                                                         
+
         gtk_notebook_set_current_page(GTK_NOTEBOOK(GLOBALS->notebook), GLOBALS->this_context_page);
         return(TRUE);
         }
-                
+
 return(FALSE);
-}                     
+}
 
 
 static int gtkwavetcl_setTabActive(ClientData clientData, Tcl_Interp *interp, int objc, Tcl_Obj *CONST objv[])
 {
 if(objc == 2)
-        {       
+        {
 	gint rc;
 
 	if(!GLOBALS->in_tcl_callback)
@@ -1875,10 +1913,10 @@ if(objc == 2)
         	char *s = get_Tcl_string(objv[1]);
         	unsigned int tabnum = atoi(s);
 		rc = switch_to_tab_number(tabnum);
-        
+
         	MaxSignalLength();
         	signalarea_configure_event(GLOBALS->signalarea, NULL);
-        
+
         	gtkwave_main_iteration();
 		}
 		else
@@ -1893,7 +1931,7 @@ if(objc == 2)
         {
         return(gtkwavetcl_badNumArgs(clientData, interp, objc, objv, 1));
         }
-       
+
 }
 
 
@@ -1907,11 +1945,11 @@ return(gtkwavetcl_printInteger(clientData, interp, objc, objv, value));
 static int gtkwavetcl_installFileFilter(ClientData clientData, Tcl_Interp *interp, int objc, Tcl_Obj *CONST objv[])
 {
 if(objc == 2)
-        {       
+        {
         char *s = get_Tcl_string(objv[1]);
         unsigned int which = atoi(s);
 	gint rc = install_file_filter(which);
-        
+
         gtkwave_main_iteration();
 	return(gtkwavetcl_printInteger(clientData, interp, objc, objv, rc));
         }
@@ -1919,14 +1957,14 @@ if(objc == 2)
         {
         return(gtkwavetcl_badNumArgs(clientData, interp, objc, objv, 1));
         }
-       
+
 }
 
 
 static int gtkwavetcl_setCurrentTranslateFile(ClientData clientData, Tcl_Interp *interp, int objc, Tcl_Obj *CONST objv[])
 {
 if(objc == 2)
-        {       
+        {
         char *s = get_Tcl_string(objv[1]);
 	set_current_translate_file(s);
 
@@ -1936,14 +1974,14 @@ if(objc == 2)
         {
         return(gtkwavetcl_badNumArgs(clientData, interp, objc, objv, 1));
         }
-       
+
 }
 
 
 static int gtkwavetcl_setCurrentTranslateEnums(ClientData clientData, Tcl_Interp *interp, int objc, Tcl_Obj *CONST objv[])
 {
 if(objc == 2)
-        {       
+        {
         char *s = get_Tcl_string(objv[1]);
 	set_current_translate_enums(s);
 
@@ -1953,18 +1991,18 @@ if(objc == 2)
         {
         return(gtkwavetcl_badNumArgs(clientData, interp, objc, objv, 1));
         }
-       
+
 }
 
 
 static int gtkwavetcl_installProcFilter(ClientData clientData, Tcl_Interp *interp, int objc, Tcl_Obj *CONST objv[])
 {
 if(objc == 2)
-        {       
+        {
         char *s = get_Tcl_string(objv[1]);
         unsigned int which = atoi(s);
 	gint rc = install_file_filter(which);
-        
+
         gtkwave_main_iteration();
 	return(gtkwavetcl_printInteger(clientData, interp, objc, objv, rc));
         }
@@ -1972,14 +2010,14 @@ if(objc == 2)
         {
         return(gtkwavetcl_badNumArgs(clientData, interp, objc, objv, 1));
         }
-       
+
 }
 
 
 static int gtkwavetcl_setCurrentTranslateProc(ClientData clientData, Tcl_Interp *interp, int objc, Tcl_Obj *CONST objv[])
 {
 if(objc == 2)
-        {       
+        {
         char *s = get_Tcl_string(objv[1]);
 	set_current_translate_proc(s);
 
@@ -1989,18 +2027,18 @@ if(objc == 2)
         {
         return(gtkwavetcl_badNumArgs(clientData, interp, objc, objv, 1));
         }
-       
+
 }
 
 
 static int gtkwavetcl_installTransFilter(ClientData clientData, Tcl_Interp *interp, int objc, Tcl_Obj *CONST objv[])
 {
 if(objc == 2)
-        {       
+        {
         char *s = get_Tcl_string(objv[1]);
         unsigned int which = atoi(s);
 	gint rc = install_ttrans_filter(which);
-        
+
         gtkwave_main_iteration();
 	return(gtkwavetcl_printInteger(clientData, interp, objc, objv, rc));
         }
@@ -2008,14 +2046,14 @@ if(objc == 2)
         {
         return(gtkwavetcl_badNumArgs(clientData, interp, objc, objv, 1));
         }
-       
+
 }
 
 
 static int gtkwavetcl_setCurrentTranslateTransProc(ClientData clientData, Tcl_Interp *interp, int objc, Tcl_Obj *CONST objv[])
 {
 if(objc == 2)
-        {       
+        {
         char *s = get_Tcl_string(objv[1]);
 	set_current_translate_ttrans(s);
 
@@ -2025,7 +2063,7 @@ if(objc == 2)
         {
         return(gtkwavetcl_badNumArgs(clientData, interp, objc, objv, 1));
         }
-       
+
 }
 
 
