@@ -1,4 +1,4 @@
-/* 
+/*
  * Copyright (c) Tony Bybell 1999-2008
  *
  * This program is free software; you can redistribute it and/or
@@ -44,9 +44,11 @@ gtk_signal_emit_by_name (GTK_OBJECT (GTK_ADJUSTMENT(GLOBALS->wave_hslider)), "ch
 gtk_signal_emit_by_name (GTK_OBJECT (GTK_ADJUSTMENT(GLOBALS->wave_hslider)), "value_changed");
 }
 
-   
+
 void from_entry_callback(GtkWidget *widget, GtkWidget *entry)
 {
+(void)widget;
+
 G_CONST_RETURN gchar *entry_text;
 TimeType newlo;
 char fromstr[40];
@@ -58,19 +60,19 @@ DEBUG(printf("From Entry contents: %s\n",entry_text));
 newlo=unformat_time(entry_text, GLOBALS->time_dimension);
 newlo -= GLOBALS->global_time_offset;
 
-if(newlo<GLOBALS->min_time) 
+if(newlo<GLOBALS->min_time)
 	{
-	newlo=GLOBALS->min_time; 
+	newlo=GLOBALS->min_time;
 	}
 
-if(newlo<(GLOBALS->tims.last)) 
-	{ 
+if(newlo<(GLOBALS->tims.last))
+	{
 	GLOBALS->tims.first=newlo;
 	if(GLOBALS->tims.start<GLOBALS->tims.first) GLOBALS->tims.timecache=GLOBALS->tims.start=GLOBALS->tims.first;
 
 	reformat_time(fromstr, GLOBALS->tims.first + GLOBALS->global_time_offset, GLOBALS->time_dimension);
 	gtk_entry_set_text(GTK_ENTRY(entry),fromstr);
-	time_update(); 
+	time_update();
 	gtkwavetcl_setvar(WAVE_TCLCB_FROM_ENTRY_UPDATED, fromstr, WAVE_TCLCB_FROM_ENTRY_UPDATED_FLAGS);
 	return;
 	}
@@ -85,6 +87,8 @@ if(newlo<(GLOBALS->tims.last))
 
 void to_entry_callback(GtkWidget *widget, GtkWidget *entry)
 {
+(void)widget;
+
 G_CONST_RETURN gchar *entry_text;
 TimeType newhi;
 char tostr[40];
@@ -96,17 +100,17 @@ DEBUG(printf("To Entry contents: %s\n",entry_text));
 newhi=unformat_time(entry_text, GLOBALS->time_dimension);
 newhi -= GLOBALS->global_time_offset;
 
-if(newhi>GLOBALS->max_time) 
+if(newhi>GLOBALS->max_time)
 	{
-	newhi=GLOBALS->max_time; 
+	newhi=GLOBALS->max_time;
 	}
 
-if(newhi>(GLOBALS->tims.first)) 
-	{ 
+if(newhi>(GLOBALS->tims.first))
+	{
 	GLOBALS->tims.last=newhi;
 	reformat_time(tostr, GLOBALS->tims.last + GLOBALS->global_time_offset, GLOBALS->time_dimension);
 	gtk_entry_set_text(GTK_ENTRY(entry),tostr);
-	time_update(); 
+	time_update();
 	gtkwavetcl_setvar(WAVE_TCLCB_TO_ENTRY_UPDATED, tostr, WAVE_TCLCB_TO_ENTRY_UPDATED_FLAGS);
 	return;
 	}
@@ -118,7 +122,7 @@ if(newhi>(GLOBALS->tims.first))
 	return;
 	}
 }
-   
+
 /* Create an entry box */
 GtkWidget *
 create_entry_box(void)
@@ -142,10 +146,10 @@ reformat_time(fromstr, GLOBALS->min_time + GLOBALS->global_time_offset, GLOBALS-
 gtk_entry_set_text(GTK_ENTRY(GLOBALS->from_entry),fromstr);
 gtk_signal_connect (GTK_OBJECT (GLOBALS->from_entry), "activate",GTK_SIGNAL_FUNC (from_entry_callback), GLOBALS->from_entry);
 box=gtk_hbox_new(FALSE, 0);
-gtk_box_pack_start(GTK_BOX(box), label, TRUE, TRUE, 0); 
+gtk_box_pack_start(GTK_BOX(box), label, TRUE, TRUE, 0);
 gtk_widget_show(label);
-gtk_box_pack_start(GTK_BOX(box), GLOBALS->from_entry, TRUE, TRUE, 0); 
-gtk_widget_set_usize(GTK_WIDGET(GLOBALS->from_entry), 90, 22); 
+gtk_box_pack_start(GTK_BOX(box), GLOBALS->from_entry, TRUE, TRUE, 0);
+gtk_widget_set_usize(GTK_WIDGET(GLOBALS->from_entry), 90, 22);
 gtk_tooltips_set_tip_2(tooltips, GLOBALS->from_entry, "Scroll Lower Bound", NULL);
 gtk_widget_show(GLOBALS->from_entry);
 
@@ -158,10 +162,10 @@ reformat_time(tostr, GLOBALS->max_time + GLOBALS->global_time_offset, GLOBALS->t
 gtk_entry_set_text(GTK_ENTRY(GLOBALS->to_entry),tostr);
 gtk_signal_connect (GTK_OBJECT (GLOBALS->to_entry), "activate",GTK_SIGNAL_FUNC (to_entry_callback), GLOBALS->to_entry);
 box2=gtk_hbox_new(FALSE, 0);
-gtk_box_pack_start(GTK_BOX(box2), label2, TRUE, TRUE, 0); 
+gtk_box_pack_start(GTK_BOX(box2), label2, TRUE, TRUE, 0);
 gtk_widget_show(label2);
-gtk_box_pack_start(GTK_BOX(box2), GLOBALS->to_entry, TRUE, TRUE, 0); 
-gtk_widget_set_usize(GTK_WIDGET(GLOBALS->to_entry), 90, 22); 
+gtk_box_pack_start(GTK_BOX(box2), GLOBALS->to_entry, TRUE, TRUE, 0);
+gtk_widget_set_usize(GTK_WIDGET(GLOBALS->to_entry), 90, 22);
 gtk_tooltips_set_tip_2(tooltips, GLOBALS->to_entry, "Scroll Upper Bound", NULL);
 gtk_widget_show(GLOBALS->to_entry);
 
@@ -181,4 +185,4 @@ gtk_widget_show(box2);
 
 return(mainbox);
 }
-   
+
