@@ -1,4 +1,4 @@
-/* 
+/*
  * Copyright (c) Tony Bybell 1999-2011.
  *
  * This program is free software; you can redistribute it and/or
@@ -19,7 +19,8 @@
 
 void dnd_setup(GtkWidget *src, GtkWidget *w, int enable_receive)
 {
-	GtkWidget *win = w;
+(void)enable_receive;
+
 	GtkTargetEntry target_entry[3];
 
 	/* Realize the clist widget and make sure it has a window,
@@ -90,6 +91,11 @@ void treeview_unselect_all_callback(void)
 static void select_row_callback(GtkWidget *widget, gint row, gint column,
         GdkEventButton *event, gpointer data)
 {
+(void)widget;
+(void)column;
+(void)event;
+(void)data;
+
 struct tree *t;
 
 t=(struct tree *)gtk_clist_get_row_data(GTK_CLIST(GLOBALS->ctree_main), row);
@@ -100,6 +106,11 @@ GLOBALS->selectedtree_treesearch_gtk1_c=t;
 static void unselect_row_callback(GtkWidget *widget, gint row, gint column,
         GdkEventButton *event, gpointer data)
 {
+(void)widget;
+(void)column;
+(void)event;
+(void)data;
+
 struct tree *t;
 
 t=(struct tree *)gtk_clist_get_row_data(GTK_CLIST(GLOBALS->ctree_main), row);
@@ -115,6 +126,9 @@ return(GLOBALS->is_active_treesearch_gtk1_c);
 
 static void enter_callback_e(GtkWidget *widget, GtkWidget *nothing)
 {
+(void)widget;
+(void)nothing;
+
   G_CONST_RETURN gchar *entry_text;
   int len;
   entry_text = gtk_entry_get_text(GTK_ENTRY(GLOBALS->entry_a_treesearch_gtk1_c));
@@ -132,6 +146,9 @@ static void enter_callback_e(GtkWidget *widget, GtkWidget *nothing)
 
 static void destroy_callback_e(GtkWidget *widget, GtkWidget *nothing)
 {
+(void)widget;
+(void)nothing;
+
   DEBUG(printf("Entry Cancel\n"));
   GLOBALS->entrybox_text_local_treesearch_gtk1_c=NULL;
   wave_gtk_grab_remove(GLOBALS->window1_treesearch_gtk1_c);
@@ -202,7 +219,7 @@ return(t);
 
 struct tree *fetchlow(struct tree *t)
 {
-if(t->child) 
+if(t->child)
 	{
 	t=t->child;
 
@@ -245,7 +262,7 @@ if(t)
 		}
 		else
 		{
-		add_vector_range(NULL, fetchlow(t)->t_which, 
+		add_vector_range(NULL, fetchlow(t)->t_which,
 			fetchhigh(t)->t_which, direction);
 		}
 	}
@@ -256,11 +273,14 @@ if(t)
 
 static void
 bundle_cleanup(GtkWidget *widget, gpointer data)
-{ 
-if(GLOBALS->entrybox_text_local_treesearch_gtk1_c) 
+{
+(void)widget;
+(void)data;
+
+if(GLOBALS->entrybox_text_local_treesearch_gtk1_c)
         {
         char *efix;
- 
+
 	if(!strlen(GLOBALS->entrybox_text_local_treesearch_gtk1_c))
 		{
 	        DEBUG(printf("Bundle name is not specified--recursing into hierarchy.\n"));
@@ -277,11 +297,11 @@ if(GLOBALS->entrybox_text_local_treesearch_gtk1_c)
 	                        }
 	                efix++;
 	                }
-	 
+
 	        DEBUG(printf("Bundle name is: %s\n",GLOBALS->entrybox_text_local_treesearch_gtk1_c));
-	        add_vector_range(GLOBALS->entrybox_text_local_treesearch_gtk1_c, 
+	        add_vector_range(GLOBALS->entrybox_text_local_treesearch_gtk1_c,
 				fetchlow(GLOBALS->selectedtree_treesearch_gtk1_c)->t_which,
-				fetchhigh(GLOBALS->selectedtree_treesearch_gtk1_c)->t_which, 
+				fetchhigh(GLOBALS->selectedtree_treesearch_gtk1_c)->t_which,
 				GLOBALS->bundle_direction_treesearch_gtk1_c);
 		}
         free_2(GLOBALS->entrybox_text_local_treesearch_gtk1_c);
@@ -296,7 +316,7 @@ MaxSignalLength();
 signalarea_configure_event(GLOBALS->signalarea, NULL);
 wavearea_configure_event(GLOBALS->wavearea, NULL);
 }
- 
+
 static void
 bundle_callback_generic(void)
 {
@@ -317,6 +337,9 @@ if(GLOBALS->selectedtree_treesearch_gtk1_c)
 static void
 bundle_callback_up(GtkWidget *widget, gpointer data)
 {
+(void)widget;
+(void)data;
+
 GLOBALS->bundle_direction_treesearch_gtk1_c=0;
 bundle_callback_generic();
 }
@@ -324,12 +347,17 @@ bundle_callback_generic();
 static void
 bundle_callback_down(GtkWidget *widget, gpointer data)
 {
+(void)widget;
+(void)data;
+
 GLOBALS->bundle_direction_treesearch_gtk1_c=1;
 bundle_callback_generic();
 }
 
 static void insert_callback(GtkWidget *widget, GtkWidget *nothing)
 {
+(void)nothing;
+
 Traces tcache;
 int i;
 
@@ -343,7 +371,7 @@ set_window_busy(widget);
 
 for(i=fetchlow(GLOBALS->selectedtree_treesearch_gtk1_c)->t_which;i<=fetchhigh(GLOBALS->selectedtree_treesearch_gtk1_c)->t_which;i++)
         {
-        struct symbol *s;  
+        struct symbol *s;
         s=GLOBALS->facs[i];
 	if(s->vec_root)
 		{
@@ -396,7 +424,7 @@ if(GLOBALS->is_lx2)
 for(i=fetchlow(GLOBALS->selectedtree_treesearch_gtk1_c)->t_which;i<=fetchhigh(GLOBALS->selectedtree_treesearch_gtk1_c)->t_which;i++)
         {
 	int len;
-        struct symbol *s, *t;  
+        struct symbol *s, *t;
         s=GLOBALS->facs[i];
 	t=s->vec_root;
 	if((t)&&(GLOBALS->autocoalesce))
@@ -415,7 +443,7 @@ for(i=fetchlow(GLOBALS->selectedtree_treesearch_gtk1_c)->t_which;i<=fetchhigh(GL
 		}
 		else
 		{
-	        AddNodeUnroll(s->n, NULL);  
+	        AddNodeUnroll(s->n, NULL);
 		}
         }
 
@@ -441,6 +469,8 @@ wavearea_configure_event(GLOBALS->wavearea, NULL);
 
 static void replace_callback(GtkWidget *widget, GtkWidget *nothing)
 {
+(void)nothing;
+
 Traces tcache;
 int i;
 Trptr tfirst=NULL, tlast=NULL;
@@ -455,7 +485,7 @@ set_window_busy(widget);
 
 for(i=fetchlow(GLOBALS->selectedtree_treesearch_gtk1_c)->t_which;i<=fetchhigh(GLOBALS->selectedtree_treesearch_gtk1_c)->t_which;i++)
         {
-        struct symbol *s;  
+        struct symbol *s;
         s=GLOBALS->facs[i];
 	if(s->vec_root)
 		{
@@ -508,7 +538,7 @@ if(GLOBALS->is_lx2)
 for(i=fetchlow(GLOBALS->selectedtree_treesearch_gtk1_c)->t_which;i<=fetchhigh(GLOBALS->selectedtree_treesearch_gtk1_c)->t_which;i++)
         {
 	int len;
-        struct symbol *s, *t;  
+        struct symbol *s, *t;
         s=GLOBALS->facs[i];
 	t=s->vec_root;
 	if((t)&&(GLOBALS->autocoalesce))
@@ -527,7 +557,7 @@ for(i=fetchlow(GLOBALS->selectedtree_treesearch_gtk1_c)->t_which;i<=fetchhigh(GL
 		}
 		else
 		{
-	        AddNodeUnroll(s->n, NULL);  
+	        AddNodeUnroll(s->n, NULL);
 		}
         }
 
@@ -598,6 +628,7 @@ wavearea_configure_event(GLOBALS->wavearea, NULL);
 
 static void ok_callback(GtkWidget *widget, GtkWidget *nothing)
 {
+(void)nothing;
 int i;
 
 if(!GLOBALS->selectedtree_treesearch_gtk1_c) return;
@@ -606,7 +637,7 @@ set_window_busy(widget);
 
 for(i=fetchlow(GLOBALS->selectedtree_treesearch_gtk1_c)->t_which;i<=fetchhigh(GLOBALS->selectedtree_treesearch_gtk1_c)->t_which;i++)
         {
-        struct symbol *s;  
+        struct symbol *s;
         s=GLOBALS->facs[i];
 	if(s->vec_root)
 		{
@@ -659,7 +690,7 @@ if(GLOBALS->is_lx2)
 for(i=fetchlow(GLOBALS->selectedtree_treesearch_gtk1_c)->t_which;i<=fetchhigh(GLOBALS->selectedtree_treesearch_gtk1_c)->t_which;i++)
         {
 	int len;
-        struct symbol *s, *t;  
+        struct symbol *s, *t;
         s=GLOBALS->facs[i];
 	t=s->vec_root;
 	if((t)&&(GLOBALS->autocoalesce))
@@ -678,7 +709,7 @@ for(i=fetchlow(GLOBALS->selectedtree_treesearch_gtk1_c)->t_which;i<=fetchhigh(GL
 		}
 		else
 		{
-	        AddNodeUnroll(s->n, NULL);  
+	        AddNodeUnroll(s->n, NULL);
 		}
         }
 
@@ -693,6 +724,9 @@ wavearea_configure_event(GLOBALS->wavearea, NULL);
 
 static void destroy_callback(GtkWidget *widget, GtkWidget *nothing)
 {
+(void)widget;
+(void)nothing;
+
   GLOBALS->is_active_treesearch_gtk1_c=0;
   gtk_widget_destroy(GLOBALS->window_treesearch_gtk1_c);
   GLOBALS->window_treesearch_gtk1_c = NULL;
@@ -705,6 +739,8 @@ static void destroy_callback(GtkWidget *widget, GtkWidget *nothing)
  */
 void treebox(char *title, GtkSignalFunc func, GtkWidget *old_window)
 {
+(void)old_window;
+
     GtkWidget *scrolled_win;
     GtkWidget *hbox;
     GtkWidget *button1, *button2, *button3, *button3a, *button4, *button5;
@@ -713,7 +749,7 @@ void treebox(char *title, GtkSignalFunc func, GtkWidget *old_window)
     GtkTooltips *tooltips;
     GtkCList  *clist;
 
-    if(GLOBALS->is_active_treesearch_gtk1_c) 
+    if(GLOBALS->is_active_treesearch_gtk1_c)
 	{
 	gdk_window_raise(GLOBALS->window_treesearch_gtk1_c->window);
 	return;
@@ -727,7 +763,7 @@ void treebox(char *title, GtkSignalFunc func, GtkWidget *old_window)
     install_focus_cb(GLOBALS->window_treesearch_gtk1_c, ((char *)&GLOBALS->window_treesearch_gtk1_c) - ((char *)GLOBALS));
 
     gtk_window_set_title(GTK_WINDOW (GLOBALS->window_treesearch_gtk1_c), title);
-    gtkwave_signal_connect(GTK_OBJECT (GLOBALS->window_treesearch_gtk1_c), "delete_event", (GtkSignalFunc) destroy_callback, NULL); 
+    gtkwave_signal_connect(GTK_OBJECT (GLOBALS->window_treesearch_gtk1_c), "delete_event", (GtkSignalFunc) destroy_callback, NULL);
 
     tooltips=gtk_tooltips_new_2();
 
@@ -784,7 +820,7 @@ void treebox(char *title, GtkSignalFunc func, GtkWidget *old_window)
     gtk_container_border_width (GTK_CONTAINER (button1), 3);
     gtkwave_signal_connect_object (GTK_OBJECT (button1), "clicked",  GTK_SIGNAL_FUNC(ok_callback), GTK_OBJECT (GLOBALS->window_treesearch_gtk1_c));
     gtk_widget_show (button1);
-    gtk_tooltips_set_tip_2(tooltips, button1, 
+    gtk_tooltips_set_tip_2(tooltips, button1,
 		"Add selected signal hierarchy to end of the display on the main window.",NULL);
 
     gtk_box_pack_start (GTK_BOX (hbox), button1, TRUE, FALSE, 0);
@@ -793,7 +829,7 @@ void treebox(char *title, GtkSignalFunc func, GtkWidget *old_window)
     gtk_container_border_width (GTK_CONTAINER (button2), 3);
     gtkwave_signal_connect_object (GTK_OBJECT (button2), "clicked", GTK_SIGNAL_FUNC(insert_callback), GTK_OBJECT (GLOBALS->window_treesearch_gtk1_c));
     gtk_widget_show (button2);
-    gtk_tooltips_set_tip_2(tooltips, button2, 
+    gtk_tooltips_set_tip_2(tooltips, button2,
 		"Add selected signal hierarchy after last highlighted signal on the main window.",NULL);
     gtk_box_pack_start (GTK_BOX (hbox), button2, TRUE, FALSE, 0);
 
@@ -803,7 +839,7 @@ void treebox(char *title, GtkSignalFunc func, GtkWidget *old_window)
     	gtk_container_border_width (GTK_CONTAINER (button3), 3);
     	gtkwave_signal_connect_object (GTK_OBJECT (button3), "clicked", GTK_SIGNAL_FUNC(bundle_callback_up), GTK_OBJECT (GLOBALS->window_treesearch_gtk1_c));
     	gtk_widget_show (button3);
-    	gtk_tooltips_set_tip_2(tooltips, button3, 
+    	gtk_tooltips_set_tip_2(tooltips, button3,
 		"Bundle selected signal hierarchy into a single bit "
 		"vector with the topmost signal as the LSB and the "
 		"lowest as the MSB.  Entering a zero length bundle "
@@ -817,7 +853,7 @@ void treebox(char *title, GtkSignalFunc func, GtkWidget *old_window)
     	gtk_container_border_width (GTK_CONTAINER (button3a), 3);
     	gtkwave_signal_connect_object (GTK_OBJECT (button3a), "clicked", GTK_SIGNAL_FUNC(bundle_callback_down), GTK_OBJECT (GLOBALS->window_treesearch_gtk1_c));
     	gtk_widget_show (button3a);
-    	gtk_tooltips_set_tip_2(tooltips, button3a, 
+    	gtk_tooltips_set_tip_2(tooltips, button3a,
 		"Bundle selected signal hierarchy into a single bit "
 		"vector with the topmost signal as the MSB and the "
 		"lowest as the LSB.  Entering a zero length bundle "
@@ -832,14 +868,14 @@ void treebox(char *title, GtkSignalFunc func, GtkWidget *old_window)
     gtk_container_border_width (GTK_CONTAINER (button4), 3);
     gtkwave_signal_connect_object (GTK_OBJECT (button4), "clicked", GTK_SIGNAL_FUNC(replace_callback), GTK_OBJECT (GLOBALS->window_treesearch_gtk1_c));
     gtk_widget_show (button4);
-    gtk_tooltips_set_tip_2(tooltips, button4, 
+    gtk_tooltips_set_tip_2(tooltips, button4,
 		"Replace highlighted signals on the main window with signals selected above.",NULL);
     gtk_box_pack_start (GTK_BOX (hbox), button4, TRUE, FALSE, 0);
 
     button5 = gtk_button_new_with_label (" Exit ");
     gtk_container_border_width (GTK_CONTAINER (button5), 3);
     gtkwave_signal_connect_object (GTK_OBJECT (button5), "clicked", GTK_SIGNAL_FUNC(destroy_callback), GTK_OBJECT (GLOBALS->window_treesearch_gtk1_c));
-    gtk_tooltips_set_tip_2(tooltips, button5, 
+    gtk_tooltips_set_tip_2(tooltips, button5,
 		"Do nothing and return to the main window.",NULL);
     gtk_widget_show (button5);
     gtk_box_pack_start (GTK_BOX (hbox), button5, TRUE, FALSE, 0);
